--[[
************************************************************************
Enchanting.lua
Enchanting data for all of Ackis Recipe List
************************************************************************
File date: 2010-03-21T14:12:41Z
File revision: @file-revision@
Project revision: @project-revision@
Project version: r20100324034041
************************************************************************
Please see http://www.wowace.com/addons/arl/ for more information.
************************************************************************
This source code is released under All Rights Reserved.
************************************************************************
]]--

-------------------------------------------------------------------------------
-- AddOn namespace.
-------------------------------------------------------------------------------
local MODNAME	= "Ackis Recipe List"
local addon	= LibStub("AceAddon-3.0"):GetAddon(MODNAME)
local L		= LibStub("AceLocale-3.0"):GetLocale(MODNAME)

local private	= select(2, ...)

-------------------------------------------------------------------------------
-- Filter flags. Acquire types, and Reputation levels.
-------------------------------------------------------------------------------
local F		= private.filter_flags
local A		= private.acquire_types
local Q		= private.item_qualities
local REP	= private.rep_levels
local FAC	= private.faction_ids
local V		= private.game_versions

local initialized = false
local num_recipes = 0

--------------------------------------------------------------------------------------------------------------------
-- Counter and wrapper function
--------------------------------------------------------------------------------------------------------------------
local function AddRecipe(spell_id, skill_level, item_id, quality, genesis, optimal_level, medium_level, easy_level, trivial_level)
	num_recipes = num_recipes + 1
	addon:AddRecipe(spell_id, skill_level, item_id, quality, 7411, nil, genesis, optimal_level, medium_level, easy_level, trivial_level)
end

function addon:InitEnchanting()
	if initialized then
		return num_recipes
	end
	initialized = true

	-- Enchant Bracer - Minor Health -- 7418
	AddRecipe(7418, 1, nil, Q.COMMON, V.ORIG, 1, 70, 90, 110)
	self:AddRecipeFlags(7418, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:AddRecipeAcquire(7418, A.CUSTOM, 8)

	-- Enchant Chest - Minor Health -- 7420
	AddRecipe(7420, 15, nil, Q.COMMON, V.ORIG, 15, 70, 90, 110)
	self:AddRecipeFlags(7420, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE)
	self:AddRecipeAcquire(7420, A.TRAINER, 1317, A.TRAINER, 3011, A.TRAINER, 3345, A.TRAINER, 3606, A.TRAINER, 4213, A.TRAINER, 4616, A.TRAINER, 5157, A.TRAINER, 5695, A.TRAINER, 11072, A.TRAINER, 11073, A.TRAINER, 11074, A.TRAINER, 16160, A.TRAINER, 16633, A.TRAINER, 16725, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 7949, A.TRAINER, 19540, A.TRAINER, 18753)

	-- Runed Copper Rod -- 7421
	AddRecipe(7421, 1, 6218, Q.COMMON, V.ORIG, 1, 5, 7, 10)
	self:AddRecipeFlags(7421, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOP, F.RBOP)
	self:AddRecipeAcquire(7421, A.CUSTOM, 8)

	-- Enchant Chest - Minor Absorption -- 7426
	AddRecipe(7426, 40, nil, Q.COMMON, V.ORIG, 40, 90, 110, 130)
	self:AddRecipeFlags(7426, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE)
	self:AddRecipeAcquire(7426, A.TRAINER, 1317, A.TRAINER, 3011, A.TRAINER, 3345, A.TRAINER, 3606, A.TRAINER, 4213, A.TRAINER, 4616, A.TRAINER, 5157, A.TRAINER, 5695, A.TRAINER, 11072, A.TRAINER, 11073, A.TRAINER, 11074, A.TRAINER, 16160, A.TRAINER, 16633, A.TRAINER, 16725, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 7949, A.TRAINER, 19540, A.TRAINER, 18753)

	-- Enchant Bracer - Minor Deflection -- 7428
	AddRecipe(7428, 1, nil, Q.COMMON, V.ORIG, 1, 80, 100, 120)
	self:AddRecipeFlags(7428, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.TANK)
	self:AddRecipeAcquire(7428, A.CUSTOM, 8)

	-- Enchant Chest - Minor Mana -- 7443
	AddRecipe(7443, 20, nil, Q.UNCOMMON, V.ORIG, 20, 80, 100, 120)
	self:AddRecipeFlags(7443, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE)
	self:AddRecipeAcquire(7443, A.WORLD_DROP, 2)

	-- Enchant Cloak - Minor Resistance -- 7454
	AddRecipe(7454, 45, nil, Q.COMMON, V.ORIG, 45, 95, 115, 135)
	self:AddRecipeFlags(7454, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE, F.CLOAK)
	self:AddRecipeAcquire(7454, A.TRAINER, 1317, A.TRAINER, 3011, A.TRAINER, 3345, A.TRAINER, 3606, A.TRAINER, 4213, A.TRAINER, 4616, A.TRAINER, 5157, A.TRAINER, 5695, A.TRAINER, 11072, A.TRAINER, 11073, A.TRAINER, 11074, A.TRAINER, 16160, A.TRAINER, 16633, A.TRAINER, 16725, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 7949, A.TRAINER, 19540, A.TRAINER, 18753)

	-- Enchant Bracer - Minor Stamina -- 7457
	AddRecipe(7457, 50, nil, Q.COMMON, V.ORIG, 50, 100, 120, 140)
	self:AddRecipeFlags(7457, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE)
	self:AddRecipeAcquire(7457, A.TRAINER, 1317, A.TRAINER, 3011, A.TRAINER, 3345, A.TRAINER, 3606, A.TRAINER, 4213, A.TRAINER, 4616, A.TRAINER, 5157, A.TRAINER, 5695, A.TRAINER, 11072, A.TRAINER, 11073, A.TRAINER, 11074, A.TRAINER, 16160, A.TRAINER, 16633, A.TRAINER, 16725, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 7949, A.TRAINER, 19540, A.TRAINER, 18753)

	-- Enchant 2H Weapon - Minor Impact -- 7745
	AddRecipe(7745, 100, nil, Q.COMMON, V.ORIG, 100, 130, 150, 170)
	self:AddRecipeFlags(7745, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE, F.TWO_HAND)
	self:AddRecipeAcquire(7745, A.TRAINER, 1317, A.TRAINER, 3011, A.TRAINER, 3345, A.TRAINER, 4213, A.TRAINER, 4616, A.TRAINER, 5157, A.TRAINER, 11072, A.TRAINER, 11073, A.TRAINER, 11074, A.TRAINER, 16633, A.TRAINER, 16725, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 3606, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 5695, A.TRAINER, 7949, A.TRAINER, 19540, A.TRAINER, 18753, A.TRAINER, 16160)

	-- Enchant Chest - Lesser Health -- 7748
	AddRecipe(7748, 60, nil, Q.COMMON, V.ORIG, 60, 105, 125, 145)
	self:AddRecipeFlags(7748, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE)
	self:AddRecipeAcquire(7748, A.TRAINER, 1317, A.TRAINER, 3011, A.TRAINER, 3345, A.TRAINER, 3606, A.TRAINER, 4213, A.TRAINER, 4616, A.TRAINER, 5157, A.TRAINER, 5695, A.TRAINER, 11072, A.TRAINER, 11073, A.TRAINER, 11074, A.TRAINER, 16160, A.TRAINER, 16633, A.TRAINER, 16725, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 7949, A.TRAINER, 19540, A.TRAINER, 18753)

	-- Enchant Bracer - Minor Spirit -- 7766
	AddRecipe(7766, 60, nil, Q.UNCOMMON, V.ORIG, 60, 105, 125, 145)
	self:AddRecipeFlags(7766, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.HEALER, F.CASTER)
	self:AddRecipeAcquire(7766, A.WORLD_DROP, 2)

	-- Enchant Cloak - Minor Protection -- 7771
	AddRecipe(7771, 70, nil, Q.COMMON, V.ORIG, 70, 110, 130, 150)
	self:AddRecipeFlags(7771, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE, F.CLOAK)
	self:AddRecipeAcquire(7771, A.TRAINER, 1317, A.TRAINER, 3011, A.TRAINER, 3345, A.TRAINER, 3606, A.TRAINER, 4213, A.TRAINER, 4616, A.TRAINER, 5157, A.TRAINER, 5695, A.TRAINER, 11072, A.TRAINER, 11073, A.TRAINER, 11074, A.TRAINER, 16160, A.TRAINER, 16633, A.TRAINER, 16725, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 7949, A.TRAINER, 19540, A.TRAINER, 18753)

	-- Enchant Chest - Lesser Mana -- 7776
	AddRecipe(7776, 80, nil, Q.UNCOMMON, V.ORIG, 80, 115, 135, 155)
	self:AddRecipeFlags(7776, F.HORDE, F.VENDOR, F.IBOE, F.RBOE)
	self:AddRecipeAcquire(7776, A.VENDOR, 3346, A.VENDOR, 5757)

	-- Enchant Bracer - Minor Agility -- 7779
	AddRecipe(7779, 80, nil, Q.COMMON, V.ORIG, 80, 115, 135, 155)
	self:AddRecipeFlags(7779, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE, F.DPS)
	self:AddRecipeAcquire(7779, A.TRAINER, 1317, A.TRAINER, 3011, A.TRAINER, 3345, A.TRAINER, 4213, A.TRAINER, 4616, A.TRAINER, 5157, A.TRAINER, 11072, A.TRAINER, 11073, A.TRAINER, 11074, A.TRAINER, 16633, A.TRAINER, 16725, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 3606, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 5695, A.TRAINER, 7949, A.TRAINER, 19540, A.TRAINER, 18753, A.TRAINER, 16160)

	-- Enchant Bracer - Minor Strength -- 7782
	AddRecipe(7782, 80, nil, Q.UNCOMMON, V.ORIG, 80, 115, 135, 155)
	self:AddRecipeFlags(7782, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.DPS)
	self:AddRecipeAcquire(7782, A.WORLD_DROP, 2)

	-- Enchant Weapon - Minor Beastslayer -- 7786
	AddRecipe(7786, 90, nil, Q.UNCOMMON, V.ORIG, 90, 120, 140, 160)
	self:AddRecipeFlags(7786, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.ONE_HAND, F.TWO_HAND)
	self:AddRecipeAcquire(7786, A.WORLD_DROP, 2)

	-- Enchant Weapon - Minor Striking -- 7788
	AddRecipe(7788, 90, nil, Q.COMMON, V.ORIG, 90, 120, 140, 160)
	self:AddRecipeFlags(7788, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE, F.ONE_HAND, F.TWO_HAND)
	self:AddRecipeAcquire(7788, A.TRAINER, 1317, A.TRAINER, 3011, A.TRAINER, 3345, A.TRAINER, 4213, A.TRAINER, 4616, A.TRAINER, 5157, A.TRAINER, 11072, A.TRAINER, 11073, A.TRAINER, 11074, A.TRAINER, 16633, A.TRAINER, 16725, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 3606, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 5695, A.TRAINER, 7949, A.TRAINER, 19540, A.TRAINER, 18753, A.TRAINER, 16160)

	-- Enchant 2H Weapon - Lesser Intellect -- 7793
	AddRecipe(7793, 100, nil, Q.COMMON, V.ORIG, 100, 130, 150, 170)
	self:AddRecipeFlags(7793, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE, F.TWO_HAND)
	self:AddRecipeAcquire(7793, A.VENDOR, 3012, A.VENDOR, 3346, A.VENDOR, 5158, A.VENDOR, 5758)

	-- Runed Silver Rod -- 7795
	AddRecipe(7795, 100, 6339, Q.COMMON, V.ORIG, 100, 130, 150, 170)
	self:AddRecipeFlags(7795, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOP, F.RBOP)
	self:AddRecipeAcquire(7795, A.TRAINER, 1317, A.TRAINER, 3011, A.TRAINER, 3345, A.TRAINER, 4213, A.TRAINER, 4616, A.TRAINER, 5157, A.TRAINER, 11072, A.TRAINER, 11073, A.TRAINER, 11074, A.TRAINER, 16633, A.TRAINER, 16725, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 3606, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 5695, A.TRAINER, 7949, A.TRAINER, 19540, A.TRAINER, 18753, A.TRAINER, 16160)

	-- Enchant Chest - Health -- 7857
	AddRecipe(7857, 120, nil, Q.COMMON, V.ORIG, 120, 145, 165, 185)
	self:AddRecipeFlags(7857, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE)
	self:AddRecipeAcquire(7857, A.TRAINER, 1317, A.TRAINER, 3011, A.TRAINER, 3345, A.TRAINER, 4213, A.TRAINER, 4616, A.TRAINER, 5157, A.TRAINER, 7949, A.TRAINER, 11072, A.TRAINER, 11073, A.TRAINER, 11074, A.TRAINER, 16633, A.TRAINER, 16725, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 3606, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 5695, A.TRAINER, 19540, A.TRAINER, 18753, A.TRAINER, 16160)

	-- Enchant Bracer - Lesser Spirit -- 7859
	AddRecipe(7859, 120, nil, Q.UNCOMMON, V.ORIG, 120, 145, 165, 185)
	self:AddRecipeFlags(7859, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.HEALER, F.CASTER)
	self:AddRecipeAcquire(7859, A.WORLD_DROP, 2)

	-- Enchant Cloak - Lesser Fire Resistance -- 7861
	AddRecipe(7861, 125, nil, Q.COMMON, V.ORIG, 125, 150, 170, 190)
	self:AddRecipeFlags(7861, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE, F.CLOAK)
	self:AddRecipeAcquire(7861, A.TRAINER, 1317, A.TRAINER, 3011, A.TRAINER, 3345, A.TRAINER, 4213, A.TRAINER, 4616, A.TRAINER, 5157, A.TRAINER, 7949, A.TRAINER, 11072, A.TRAINER, 11073, A.TRAINER, 11074, A.TRAINER, 16633, A.TRAINER, 16725, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 3606, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 5695, A.TRAINER, 19540, A.TRAINER, 18753, A.TRAINER, 16160)

	-- Enchant Boots - Minor Stamina -- 7863
	AddRecipe(7863, 125, nil, Q.COMMON, V.ORIG, 125, 150, 170, 190)
	self:AddRecipeFlags(7863, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE)
	self:AddRecipeAcquire(7863, A.TRAINER, 1317, A.TRAINER, 3011, A.TRAINER, 3345, A.TRAINER, 4213, A.TRAINER, 4616, A.TRAINER, 5157, A.TRAINER, 7949, A.TRAINER, 11072, A.TRAINER, 11073, A.TRAINER, 11074, A.TRAINER, 16633, A.TRAINER, 16725, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 3606, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 5695, A.TRAINER, 19540, A.TRAINER, 18753, A.TRAINER, 16160)

	-- Enchant Boots - Minor Agility -- 7867
	AddRecipe(7867, 125, nil, Q.UNCOMMON, V.ORIG, 125, 150, 170, 190)
	self:AddRecipeFlags(7867, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE, F.DPS)
	self:AddRecipeAcquire(7867, A.VENDOR, 3012, A.VENDOR, 3537)

	-- Enchant Shield - Minor Stamina -- 13378
	AddRecipe(13378, 105, nil, Q.COMMON, V.ORIG, 105, 130, 150, 170)
	self:AddRecipeFlags(13378, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE, F.SHIELD)
	self:AddRecipeAcquire(13378, A.TRAINER, 1317, A.TRAINER, 3011, A.TRAINER, 3345, A.TRAINER, 4213, A.TRAINER, 4616, A.TRAINER, 5157, A.TRAINER, 7949, A.TRAINER, 11072, A.TRAINER, 11073, A.TRAINER, 11074, A.TRAINER, 16633, A.TRAINER, 16725, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 3606, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 19540, A.TRAINER, 18753, A.TRAINER, 16160)

	-- Enchant 2H Weapon - Lesser Spirit -- 13380
	AddRecipe(13380, 110, nil, Q.UNCOMMON, V.ORIG, 110, 135, 155, 175)
	self:AddRecipeFlags(13380, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.TWO_HAND)
	self:AddRecipeAcquire(13380, A.WORLD_DROP, 2)

	-- Enchant Cloak - Minor Agility -- 13419
	AddRecipe(13419, 110, nil, Q.UNCOMMON, V.ORIG, 110, 135, 155, 175)
	self:AddRecipeFlags(13419, F.ALLIANCE, F.HORDE, F.VENDOR, F.WORLD_DROP, F.IBOE, F.RBOE, F.DPS, F.CLOAK)
	self:AddRecipeAcquire(13419, A.WORLD_DROP, 2, A.VENDOR, 3954, A.VENDOR, 12043)

	-- Enchant Cloak - Lesser Protection -- 13421
	AddRecipe(13421, 115, nil, Q.COMMON, V.ORIG, 115, 140, 160, 180)
	self:AddRecipeFlags(13421, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE, F.CLOAK)
	self:AddRecipeAcquire(13421, A.TRAINER, 1317, A.TRAINER, 3011, A.TRAINER, 3345, A.TRAINER, 4213, A.TRAINER, 4616, A.TRAINER, 5157, A.TRAINER, 7949, A.TRAINER, 11072, A.TRAINER, 11073, A.TRAINER, 11074, A.TRAINER, 16633, A.TRAINER, 16725, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 3606, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 5695, A.TRAINER, 19540, A.TRAINER, 18753, A.TRAINER, 16160)

	-- Enchant Shield - Lesser Protection -- 13464
	AddRecipe(13464, 115, nil, Q.UNCOMMON, V.ORIG, 115, 140, 160, 180)
	self:AddRecipeFlags(13464, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.SHIELD)
	self:AddRecipeAcquire(13464, A.WORLD_DROP, 2)

	-- Enchant Shield - Lesser Spirit -- 13485
	AddRecipe(13485, 130, nil, Q.COMMON, V.ORIG, 130, 155, 175, 195)
	self:AddRecipeFlags(13485, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.SHIELD)
	self:AddRecipeAcquire(13485, A.TRAINER, 1317, A.TRAINER, 3011, A.TRAINER, 3345, A.TRAINER, 4213, A.TRAINER, 4616, A.TRAINER, 5157, A.TRAINER, 7949, A.TRAINER, 11072, A.TRAINER, 11073, A.TRAINER, 11074, A.TRAINER, 16633, A.TRAINER, 16725, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 3606, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 5695, A.TRAINER, 19540, A.TRAINER, 18753, A.TRAINER, 16160)

	-- Enchant Bracer - Lesser Stamina -- 13501
	AddRecipe(13501, 130, nil, Q.COMMON, V.ORIG, 130, 155, 175, 195)
	self:AddRecipeFlags(13501, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE)
	self:AddRecipeAcquire(13501, A.TRAINER, 1317, A.TRAINER, 3011, A.TRAINER, 3345, A.TRAINER, 4213, A.TRAINER, 4616, A.TRAINER, 5157, A.TRAINER, 7949, A.TRAINER, 11072, A.TRAINER, 11073, A.TRAINER, 11074, A.TRAINER, 16633, A.TRAINER, 16725, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 3606, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 5695, A.TRAINER, 19540, A.TRAINER, 18753, A.TRAINER, 16160)

	-- Enchant Weapon - Lesser Striking -- 13503
	AddRecipe(13503, 140, nil, Q.COMMON, V.ORIG, 140, 165, 185, 205)
	self:AddRecipeFlags(13503, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE, F.ONE_HAND, F.TWO_HAND)
	self:AddRecipeAcquire(13503, A.TRAINER, 1317, A.TRAINER, 3011, A.TRAINER, 3345, A.TRAINER, 4213, A.TRAINER, 4616, A.TRAINER, 5157, A.TRAINER, 7949, A.TRAINER, 11072, A.TRAINER, 11073, A.TRAINER, 11074, A.TRAINER, 16633, A.TRAINER, 16725, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 3606, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 5695, A.TRAINER, 19540, A.TRAINER, 18753, A.TRAINER, 16160)

	-- Enchant Cloak - Lesser Shadow Resistance -- 13522
	AddRecipe(13522, 135, nil, Q.UNCOMMON, V.ORIG, 135, 160, 180, 200)
	self:AddRecipeFlags(13522, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.CLOAK)
	self:AddRecipeAcquire(13522, A.WORLD_DROP, 2)

	-- Enchant 2H Weapon - Lesser Impact -- 13529
	AddRecipe(13529, 145, nil, Q.COMMON, V.ORIG, 145, 170, 190, 210)
	self:AddRecipeFlags(13529, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE, F.TWO_HAND)
	self:AddRecipeAcquire(13529, A.TRAINER, 1317, A.TRAINER, 3011, A.TRAINER, 3345, A.TRAINER, 4213, A.TRAINER, 4616, A.TRAINER, 5157, A.TRAINER, 7949, A.TRAINER, 11072, A.TRAINER, 11073, A.TRAINER, 11074, A.TRAINER, 16633, A.TRAINER, 16725, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 3606, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 5695, A.TRAINER, 19540, A.TRAINER, 18753, A.TRAINER, 16160)

	-- Enchant Bracer - Lesser Strength -- 13536
	AddRecipe(13536, 140, nil, Q.COMMON, V.ORIG, 140, 165, 185, 205)
	self:AddRecipeFlags(13536, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE, F.DPS)
	self:AddRecipeAcquire(13536, A.VENDOR, 3954, A.VENDOR, 12043)

	-- Enchant Chest - Lesser Absorption -- 13538
	AddRecipe(13538, 140, nil, Q.COMMON, V.ORIG, 140, 165, 185, 205)
	self:AddRecipeFlags(13538, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE)
	self:AddRecipeAcquire(13538, A.TRAINER, 1317, A.TRAINER, 3011, A.TRAINER, 3345, A.TRAINER, 4213, A.TRAINER, 4616, A.TRAINER, 5157, A.TRAINER, 7949, A.TRAINER, 11072, A.TRAINER, 11073, A.TRAINER, 11074, A.TRAINER, 16633, A.TRAINER, 16725, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 3606, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 5695, A.TRAINER, 19540, A.TRAINER, 18753, A.TRAINER, 16160)

	-- Enchant Chest - Mana -- 13607
	AddRecipe(13607, 145, nil, Q.COMMON, V.ORIG, 145, 170, 190, 210)
	self:AddRecipeFlags(13607, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE)
	self:AddRecipeAcquire(13607, A.TRAINER, 1317, A.TRAINER, 3011, A.TRAINER, 3345, A.TRAINER, 4213, A.TRAINER, 4616, A.TRAINER, 5157, A.TRAINER, 7949, A.TRAINER, 11072, A.TRAINER, 11073, A.TRAINER, 11074, A.TRAINER, 16633, A.TRAINER, 16725, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 3606, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 5695, A.TRAINER, 19540, A.TRAINER, 18753, A.TRAINER, 16160)

	-- Enchant Gloves - Mining -- 13612
	AddRecipe(13612, 145, nil, Q.COMMON, V.ORIG, 145, 170, 190, 210)
	self:AddRecipeFlags(13612, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOE)
	self:AddRecipeAcquire(13612, A.MOB, 1054, A.MOB, 1051, A.MOB, 1052, A.MOB, 1053, A.MOB, 1364)

	-- Enchant Gloves - Herbalism -- 13617
	AddRecipe(13617, 145, nil, Q.COMMON, V.ORIG, 145, 170, 190, 210)
	self:AddRecipeFlags(13617, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOE)
	self:AddRecipeAcquire(13617, A.MOB, 4030, A.MOB, 4029, A.MOB, 3834, A.MOB, 3919, A.MOB, 4028)

	-- Enchant Gloves - Fishing -- 13620
	AddRecipe(13620, 145, nil, Q.COMMON, V.ORIG, 145, 170, 190, 210)
	self:AddRecipeFlags(13620, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOE)
	self:AddRecipeAcquire(13620, A.MOB, 2375, A.MOB, 2377, A.MOB, 2376, A.MOB, 2374, A.MOB, 14276)

	-- Enchant Bracer - Lesser Intellect -- 13622
	AddRecipe(13622, 150, nil, Q.COMMON, V.ORIG, 150, 175, 195, 215)
	self:AddRecipeFlags(13622, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE)
	self:AddRecipeAcquire(13622, A.TRAINER, 1317, A.TRAINER, 3011, A.TRAINER, 3345, A.TRAINER, 4213, A.TRAINER, 4616, A.TRAINER, 5157, A.TRAINER, 7949, A.TRAINER, 11072, A.TRAINER, 11073, A.TRAINER, 11074, A.TRAINER, 16633, A.TRAINER, 16725, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 3606, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 5695, A.TRAINER, 19540, A.TRAINER, 18753, A.TRAINER, 16160)

	-- Enchant Chest - Minor Stats -- 13626
	AddRecipe(13626, 150, nil, Q.COMMON, V.ORIG, 150, 175, 195, 215)
	self:AddRecipeFlags(13626, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE)
	self:AddRecipeAcquire(13626, A.TRAINER, 1317, A.TRAINER, 3011, A.TRAINER, 3345, A.TRAINER, 4213, A.TRAINER, 4616, A.TRAINER, 5157, A.TRAINER, 7949, A.TRAINER, 11072, A.TRAINER, 11073, A.TRAINER, 11074, A.TRAINER, 16633, A.TRAINER, 16725, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 3606, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 5695, A.TRAINER, 19540, A.TRAINER, 18753, A.TRAINER, 16160)

	-- Runed Golden Rod -- 13628
	AddRecipe(13628, 150, 11130, Q.COMMON, V.ORIG, 150, 175, 195, 215)
	self:AddRecipeFlags(13628, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOP, F.RBOP)
	self:AddRecipeAcquire(13628, A.TRAINER, 1317, A.TRAINER, 3011, A.TRAINER, 3345, A.TRAINER, 4213, A.TRAINER, 4616, A.TRAINER, 5157, A.TRAINER, 7949, A.TRAINER, 11072, A.TRAINER, 11073, A.TRAINER, 11074, A.TRAINER, 16633, A.TRAINER, 16725, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 3606, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 5695, A.TRAINER, 19540, A.TRAINER, 18753, A.TRAINER, 16160)

	-- Enchant Shield - Lesser Stamina -- 13631
	AddRecipe(13631, 155, nil, Q.COMMON, V.ORIG, 155, 175, 195, 215)
	self:AddRecipeFlags(13631, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE, F.SHIELD)
	self:AddRecipeAcquire(13631, A.TRAINER, 11072, A.TRAINER, 11073, A.TRAINER, 11074, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 16633, A.TRAINER, 1317, A.TRAINER, 3606, A.TRAINER, 4213, A.TRAINER, 16725, A.TRAINER, 3345, A.TRAINER, 3011, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 5695, A.TRAINER, 4616, A.TRAINER, 7949, A.TRAINER, 5157, A.TRAINER, 19540, A.TRAINER, 18753, A.TRAINER, 16160)

	-- Enchant Cloak - Defense -- 13635
	AddRecipe(13635, 155, nil, Q.COMMON, V.ORIG, 155, 175, 195, 215)
	self:AddRecipeFlags(13635, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE, F.TANK, F.CLOAK)
	self:AddRecipeAcquire(13635, A.TRAINER, 11072, A.TRAINER, 11073, A.TRAINER, 11074, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 16633, A.TRAINER, 1317, A.TRAINER, 3606, A.TRAINER, 4213, A.TRAINER, 16725, A.TRAINER, 3345, A.TRAINER, 3011, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 5695, A.TRAINER, 4616, A.TRAINER, 7949, A.TRAINER, 5157, A.TRAINER, 19540, A.TRAINER, 18753, A.TRAINER, 16160)

	-- Enchant Boots - Lesser Agility -- 13637
	AddRecipe(13637, 160, nil, Q.COMMON, V.ORIG, 160, 180, 200, 220)
	self:AddRecipeFlags(13637, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE, F.DPS)
	self:AddRecipeAcquire(13637, A.TRAINER, 11072, A.TRAINER, 11073, A.TRAINER, 11074, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 16633, A.TRAINER, 1317, A.TRAINER, 3606, A.TRAINER, 4213, A.TRAINER, 16725, A.TRAINER, 3345, A.TRAINER, 3011, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 5695, A.TRAINER, 4616, A.TRAINER, 7949, A.TRAINER, 5157, A.TRAINER, 19540, A.TRAINER, 18753, A.TRAINER, 16160)

	-- Enchant Chest - Greater Health -- 13640
	AddRecipe(13640, 160, nil, Q.COMMON, V.ORIG, 160, 180, 200, 220)
	self:AddRecipeFlags(13640, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE)
	self:AddRecipeAcquire(13640, A.TRAINER, 11072, A.TRAINER, 11073, A.TRAINER, 11074, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 16633, A.TRAINER, 1317, A.TRAINER, 3606, A.TRAINER, 4213, A.TRAINER, 16725, A.TRAINER, 3345, A.TRAINER, 3011, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 5695, A.TRAINER, 4616, A.TRAINER, 7949, A.TRAINER, 5157, A.TRAINER, 19540, A.TRAINER, 18753, A.TRAINER, 16160)

	-- Enchant Bracer - Spirit -- 13642
	AddRecipe(13642, 165, nil, Q.COMMON, V.ORIG, 165, 185, 205, 225)
	self:AddRecipeFlags(13642, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE, F.HEALER, F.CASTER)
	self:AddRecipeAcquire(13642, A.TRAINER, 11072, A.TRAINER, 11073, A.TRAINER, 11074, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 16633, A.TRAINER, 1317, A.TRAINER, 3606, A.TRAINER, 4213, A.TRAINER, 16725, A.TRAINER, 3345, A.TRAINER, 3011, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 5695, A.TRAINER, 4616, A.TRAINER, 7949, A.TRAINER, 5157, A.TRAINER, 19540, A.TRAINER, 18753, A.TRAINER, 16160)

	-- Enchant Boots - Lesser Stamina -- 13644
	AddRecipe(13644, 170, nil, Q.COMMON, V.ORIG, 170, 190, 210, 230)
	self:AddRecipeFlags(13644, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE)
	self:AddRecipeAcquire(13644, A.TRAINER, 11072, A.TRAINER, 11073, A.TRAINER, 11074, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 16633, A.TRAINER, 1317, A.TRAINER, 3606, A.TRAINER, 4213, A.TRAINER, 16725, A.TRAINER, 3345, A.TRAINER, 3011, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 5695, A.TRAINER, 4616, A.TRAINER, 7949, A.TRAINER, 5157, A.TRAINER, 19540, A.TRAINER, 18753, A.TRAINER, 16160)

	-- Enchant Bracer - Lesser Deflection -- 13646
	AddRecipe(13646, 170, nil, Q.COMMON, V.ORIG, 170, 190, 210, 230)
	self:AddRecipeFlags(13646, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE, F.TANK)
	self:AddRecipeAcquire(13646, A.VENDOR, 2381, A.VENDOR, 2821)

	-- Enchant Bracer - Stamina -- 13648
	AddRecipe(13648, 170, nil, Q.COMMON, V.ORIG, 170, 190, 210, 230)
	self:AddRecipeFlags(13648, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE)
	self:AddRecipeAcquire(13648, A.TRAINER, 11072, A.TRAINER, 11073, A.TRAINER, 11074, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 16633, A.TRAINER, 1317, A.TRAINER, 3606, A.TRAINER, 4213, A.TRAINER, 16725, A.TRAINER, 3345, A.TRAINER, 3011, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 5695, A.TRAINER, 4616, A.TRAINER, 7949, A.TRAINER, 5157, A.TRAINER, 19540, A.TRAINER, 18753, A.TRAINER, 16160)

	-- Enchant Weapon - Lesser Beastslayer -- 13653
	AddRecipe(13653, 175, nil, Q.UNCOMMON, V.ORIG, 175, 195, 215, 235)
	self:AddRecipeFlags(13653, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.ONE_HAND, F.TWO_HAND)
	self:AddRecipeAcquire(13653, A.WORLD_DROP, 2)

	-- Enchant Weapon - Lesser Elemental Slayer -- 13655
	AddRecipe(13655, 175, nil, Q.UNCOMMON, V.ORIG, 175, 195, 215, 235)
	self:AddRecipeFlags(13655, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.ONE_HAND, F.TWO_HAND)
	self:AddRecipeAcquire(13655, A.WORLD_DROP, 2)

	-- Enchant Cloak - Fire Resistance -- 13657
	AddRecipe(13657, 175, nil, Q.COMMON, V.ORIG, 175, 195, 215, 235)
	self:AddRecipeFlags(13657, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE, F.CLOAK)
	self:AddRecipeAcquire(13657, A.TRAINER, 11072, A.TRAINER, 11073, A.TRAINER, 11074, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 16633, A.TRAINER, 1317, A.TRAINER, 3606, A.TRAINER, 4213, A.TRAINER, 16725, A.TRAINER, 3345, A.TRAINER, 3011, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 5695, A.TRAINER, 4616, A.TRAINER, 7949, A.TRAINER, 5157, A.TRAINER, 19540, A.TRAINER, 18753, A.TRAINER, 16160)

	-- Enchant Shield - Spirit -- 13659
	AddRecipe(13659, 180, nil, Q.COMMON, V.ORIG, 180, 200, 220, 240)
	self:AddRecipeFlags(13659, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.SHIELD)
	self:AddRecipeAcquire(13659, A.TRAINER, 11072, A.TRAINER, 11073, A.TRAINER, 11074, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 16633, A.TRAINER, 1317, A.TRAINER, 3606, A.TRAINER, 4213, A.TRAINER, 16725, A.TRAINER, 3345, A.TRAINER, 3011, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 5695, A.TRAINER, 4616, A.TRAINER, 7949, A.TRAINER, 5157, A.TRAINER, 19540, A.TRAINER, 18753, A.TRAINER, 16160)

	-- Enchant Bracer - Strength -- 13661
	AddRecipe(13661, 180, nil, Q.COMMON, V.ORIG, 180, 200, 220, 240)
	self:AddRecipeFlags(13661, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE, F.DPS)
	self:AddRecipeAcquire(13661, A.TRAINER, 11072, A.TRAINER, 11073, A.TRAINER, 11074, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 16633, A.TRAINER, 1317, A.TRAINER, 3606, A.TRAINER, 4213, A.TRAINER, 16725, A.TRAINER, 3345, A.TRAINER, 3011, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 5695, A.TRAINER, 4616, A.TRAINER, 7949, A.TRAINER, 5157, A.TRAINER, 19540, A.TRAINER, 18753, A.TRAINER, 16160)

	-- Enchant Chest - Greater Mana -- 13663
	AddRecipe(13663, 185, nil, Q.COMMON, V.ORIG, 185, 205, 225, 245)
	self:AddRecipeFlags(13663, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE)
	self:AddRecipeAcquire(13663, A.TRAINER, 11072, A.TRAINER, 11073, A.TRAINER, 11074, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 16633, A.TRAINER, 1317, A.TRAINER, 3606, A.TRAINER, 4213, A.TRAINER, 16725, A.TRAINER, 3345, A.TRAINER, 3011, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 5695, A.TRAINER, 4616, A.TRAINER, 7949, A.TRAINER, 5157, A.TRAINER, 19540, A.TRAINER, 18753, A.TRAINER, 16160)

	-- Enchant Boots - Lesser Spirit -- 13687
	AddRecipe(13687, 190, nil, Q.UNCOMMON, V.ORIG, 190, 210, 230, 250)
	self:AddRecipeFlags(13687, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.HEALER, F.CASTER)
	self:AddRecipeAcquire(13687, A.WORLD_DROP, 2)

	-- Enchant Shield - Lesser Block -- 13689
	AddRecipe(13689, 195, nil, Q.UNCOMMON, V.ORIG, 195, 215, 235, 255)
	self:AddRecipeFlags(13689, F.ALLIANCE, F.HORDE, F.INSTANCE, F.WORLD_DROP, F.IBOE, F.RBOE, F.TANK, F.SHIELD)
	self:AddRecipeAcquire(13689, A.WORLD_DROP, 2)

	-- Enchant Weapon - Striking -- 13693
	AddRecipe(13693, 195, nil, Q.COMMON, V.ORIG, 195, 215, 235, 255)
	self:AddRecipeFlags(13693, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE, F.ONE_HAND, F.TWO_HAND)
	self:AddRecipeAcquire(13693, A.TRAINER, 11072, A.TRAINER, 11073, A.TRAINER, 11074, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 16633, A.TRAINER, 1317, A.TRAINER, 3606, A.TRAINER, 4213, A.TRAINER, 16725, A.TRAINER, 3345, A.TRAINER, 3011, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 5695, A.TRAINER, 4616, A.TRAINER, 7949, A.TRAINER, 5157, A.TRAINER, 19540, A.TRAINER, 18753, A.TRAINER, 16160)

	-- Enchant 2H Weapon - Impact -- 13695
	AddRecipe(13695, 200, nil, Q.COMMON, V.ORIG, 200, 220, 240, 260)
	self:AddRecipeFlags(13695, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE, F.TWO_HAND)
	self:AddRecipeAcquire(13695, A.TRAINER, 11072, A.TRAINER, 11073, A.TRAINER, 11074, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 16633, A.TRAINER, 1317, A.TRAINER, 3606, A.TRAINER, 4213, A.TRAINER, 16725, A.TRAINER, 3345, A.TRAINER, 3011, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 5695, A.TRAINER, 4616, A.TRAINER, 7949, A.TRAINER, 5157, A.TRAINER, 19540, A.TRAINER, 18753, A.TRAINER, 16160)

	-- Enchant Gloves - Skinning -- 13698
	AddRecipe(13698, 200, nil, Q.COMMON, V.ORIG, 200, 220, 240, 260)
	self:AddRecipeFlags(13698, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOE)
	self:AddRecipeAcquire(13698, A.MOB, 2556, A.MOB, 2557, A.MOB, 2558, A.MOB, 2606)

	-- Enchant Chest - Lesser Stats -- 13700
	AddRecipe(13700, 200, nil, Q.COMMON, V.ORIG, 200, 220, 240, 260)
	self:AddRecipeFlags(13700, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE)
	self:AddRecipeAcquire(13700, A.TRAINER, 11072, A.TRAINER, 11073, A.TRAINER, 11074, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 16633, A.TRAINER, 1317, A.TRAINER, 3606, A.TRAINER, 4213, A.TRAINER, 16725, A.TRAINER, 3345, A.TRAINER, 3011, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 5695, A.TRAINER, 4616, A.TRAINER, 7949, A.TRAINER, 5157, A.TRAINER, 19540, A.TRAINER, 18753, A.TRAINER, 16160)

	-- Runed Truesilver Rod -- 13702
	AddRecipe(13702, 200, 11145, Q.COMMON, V.ORIG, 200, 220, 240, 260)
	self:AddRecipeFlags(13702, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOP, F.RBOP)
	self:AddRecipeAcquire(13702, A.TRAINER, 11072, A.TRAINER, 11073, A.TRAINER, 11074, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 16633, A.TRAINER, 1317, A.TRAINER, 3606, A.TRAINER, 4213, A.TRAINER, 16725, A.TRAINER, 3345, A.TRAINER, 3011, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 5695, A.TRAINER, 4616, A.TRAINER, 7949, A.TRAINER, 5157, A.TRAINER, 19540, A.TRAINER, 18753, A.TRAINER, 16160)

	-- Enchant Cloak - Greater Defense -- 13746
	AddRecipe(13746, 205, nil, Q.COMMON, V.ORIG, 205, 225, 245, 265)
	self:AddRecipeFlags(13746, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE, F.TANK, F.CLOAK)
	self:AddRecipeAcquire(13746, A.TRAINER, 11072, A.TRAINER, 11073, A.TRAINER, 11074, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 16633, A.TRAINER, 1317, A.TRAINER, 3606, A.TRAINER, 4213, A.TRAINER, 16725, A.TRAINER, 3345, A.TRAINER, 3011, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 5695, A.TRAINER, 4616, A.TRAINER, 7949, A.TRAINER, 5157, A.TRAINER, 19540, A.TRAINER, 18753, A.TRAINER, 16160)

	-- Enchant Cloak - Resistance -- 13794
	AddRecipe(13794, 205, nil, Q.COMMON, V.ORIG, 205, 225, 245, 265)
	self:AddRecipeFlags(13794, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE, F.CLOAK)
	self:AddRecipeAcquire(13794, A.TRAINER, 11072, A.TRAINER, 11073, A.TRAINER, 11074, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 16633, A.TRAINER, 1317, A.TRAINER, 3606, A.TRAINER, 4213, A.TRAINER, 16725, A.TRAINER, 3345, A.TRAINER, 3011, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 5695, A.TRAINER, 4616, A.TRAINER, 7949, A.TRAINER, 5157, A.TRAINER, 19540, A.TRAINER, 18753, A.TRAINER, 16160)

	-- Enchant Gloves - Agility -- 13815
	AddRecipe(13815, 210, nil, Q.COMMON, V.ORIG, 210, 230, 250, 270)
	self:AddRecipeFlags(13815, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE, F.DPS)
	self:AddRecipeAcquire(13815, A.TRAINER, 11072, A.TRAINER, 11073, A.TRAINER, 11074, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 16633, A.TRAINER, 1317, A.TRAINER, 3606, A.TRAINER, 4213, A.TRAINER, 16725, A.TRAINER, 3345, A.TRAINER, 3011, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 5695, A.TRAINER, 4616, A.TRAINER, 7949, A.TRAINER, 5157, A.TRAINER, 19540, A.TRAINER, 18753, A.TRAINER, 16160)

	-- Enchant Shield - Stamina -- 13817
	AddRecipe(13817, 210, nil, Q.UNCOMMON, V.ORIG, 210, 230, 250, 270)
	self:AddRecipeFlags(13817, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.SHIELD)
	self:AddRecipeAcquire(13817, A.WORLD_DROP, 2)

	-- Enchant Bracer - Intellect -- 13822
	AddRecipe(13822, 210, nil, Q.COMMON, V.ORIG, 210, 230, 250, 270)
	self:AddRecipeFlags(13822, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE)
	self:AddRecipeAcquire(13822, A.TRAINER, 11072, A.TRAINER, 11073, A.TRAINER, 11074, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 16633, A.TRAINER, 1317, A.TRAINER, 3606, A.TRAINER, 4213, A.TRAINER, 16725, A.TRAINER, 3345, A.TRAINER, 3011, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 5695, A.TRAINER, 4616, A.TRAINER, 7949, A.TRAINER, 5157, A.TRAINER, 19540, A.TRAINER, 18753, A.TRAINER, 16160)

	-- Enchant Boots - Stamina -- 13836
	AddRecipe(13836, 215, nil, Q.COMMON, V.ORIG, 215, 235, 255, 275)
	self:AddRecipeFlags(13836, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE)
	self:AddRecipeAcquire(13836, A.TRAINER, 11072, A.TRAINER, 11073, A.TRAINER, 11074, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 16633, A.TRAINER, 1317, A.TRAINER, 3606, A.TRAINER, 4213, A.TRAINER, 16725, A.TRAINER, 3345, A.TRAINER, 3011, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 5695, A.TRAINER, 4616, A.TRAINER, 7949, A.TRAINER, 5157, A.TRAINER, 19540, A.TRAINER, 18753, A.TRAINER, 16160)

	-- Enchant Gloves - Advanced Mining -- 13841
	AddRecipe(13841, 215, nil, Q.COMMON, V.ORIG, 215, 235, 255, 275)
	self:AddRecipeFlags(13841, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOE)
	self:AddRecipeAcquire(13841, A.MOB, 674)

	-- Enchant Bracer - Greater Spirit -- 13846
	AddRecipe(13846, 220, nil, Q.UNCOMMON, V.ORIG, 220, 240, 260, 280)
	self:AddRecipeFlags(13846, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.HEALER, F.CASTER)
	self:AddRecipeAcquire(13846, A.WORLD_DROP, 2)

	-- Enchant Chest - Superior Health -- 13858
	AddRecipe(13858, 220, nil, Q.COMMON, V.ORIG, 220, 240, 260, 280)
	self:AddRecipeFlags(13858, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE)
	self:AddRecipeAcquire(13858, A.TRAINER, 11072, A.TRAINER, 11073, A.TRAINER, 11074, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 16633, A.TRAINER, 1317, A.TRAINER, 3606, A.TRAINER, 4213, A.TRAINER, 16725, A.TRAINER, 3345, A.TRAINER, 3011, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 5695, A.TRAINER, 4616, A.TRAINER, 7949, A.TRAINER, 5157, A.TRAINER, 19540, A.TRAINER, 18753, A.TRAINER, 16160)

	-- Enchant Gloves - Advanced Herbalism -- 13868
	AddRecipe(13868, 225, nil, Q.COMMON, V.ORIG, 225, 245, 265, 285)
	self:AddRecipeFlags(13868, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOE)
	self:AddRecipeAcquire(13868, A.MOB, 764, A.MOB, 765, A.MOB, 766, A.MOB, 1081, A.MOB, 14448)

	-- Enchant Cloak - Lesser Agility -- 13882
	AddRecipe(13882, 225, nil, Q.COMMON, V.ORIG, 225, 245, 265, 285)
	self:AddRecipeFlags(13882, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOE, F.DPS, F.CLOAK)
	self:AddRecipeAcquire(13882, A.MOB, 2246, A.MOB, 5623, A.MOB, 7805)

	-- Enchant Gloves - Strength -- 13887
	AddRecipe(13887, 225, nil, Q.COMMON, V.ORIG, 225, 245, 265, 285)
	self:AddRecipeFlags(13887, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE, F.DPS)
	self:AddRecipeAcquire(13887, A.TRAINER, 11072, A.TRAINER, 11073, A.TRAINER, 11074, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 16633, A.TRAINER, 1317, A.TRAINER, 3606, A.TRAINER, 4213, A.TRAINER, 16725, A.TRAINER, 3345, A.TRAINER, 3011, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 5695, A.TRAINER, 4616, A.TRAINER, 7949, A.TRAINER, 5157, A.TRAINER, 19540, A.TRAINER, 18753, A.TRAINER, 16160)

	-- Enchant Boots - Minor Speed -- 13890
	AddRecipe(13890, 225, nil, Q.COMMON, V.ORIG, 225, 245, 265, 285)
	self:AddRecipeFlags(13890, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE)
	self:AddRecipeAcquire(13890, A.TRAINER, 11072, A.TRAINER, 11073, A.TRAINER, 11074, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 16633, A.TRAINER, 1317, A.TRAINER, 3606, A.TRAINER, 4213, A.TRAINER, 16725, A.TRAINER, 3345, A.TRAINER, 3011, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 5695, A.TRAINER, 4616, A.TRAINER, 7949, A.TRAINER, 5157, A.TRAINER, 19540, A.TRAINER, 18753, A.TRAINER, 16160)

	-- Enchant Weapon - Fiery Weapon -- 13898
	AddRecipe(13898, 265, nil, Q.COMMON, V.ORIG, 265, 285, 305, 325)
	self:AddRecipeFlags(13898, F.ALLIANCE, F.HORDE, F.INSTANCE, F.IBOE, F.RBOE, F.ONE_HAND, F.TWO_HAND)
	self:AddRecipeAcquire(13898, A.MOB, 9024)

	-- Enchant Shield - Greater Spirit -- 13905
	AddRecipe(13905, 230, nil, Q.COMMON, V.ORIG, 230, 250, 270, 290)
	self:AddRecipeFlags(13905, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.SHIELD)
	self:AddRecipeAcquire(13905, A.TRAINER, 11073, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 16633, A.TRAINER, 11072, A.TRAINER, 1317, A.TRAINER, 3606, A.TRAINER, 4213, A.TRAINER, 16725, A.TRAINER, 3345, A.TRAINER, 3011, A.TRAINER, 11074, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 5695, A.TRAINER, 4616, A.TRAINER, 7949, A.TRAINER, 5157, A.TRAINER, 19540, A.TRAINER, 18753, A.TRAINER, 16160)

	-- Enchant Weapon - Demonslaying -- 13915
	AddRecipe(13915, 230, nil, Q.UNCOMMON, V.ORIG, 230, 250, 270, 290)
	self:AddRecipeFlags(13915, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.ONE_HAND, F.TWO_HAND)
	self:AddRecipeAcquire(13915, A.WORLD_DROP, 2)

	-- Enchant Chest - Superior Mana -- 13917
	AddRecipe(13917, 230, nil, Q.COMMON, V.ORIG, 230, 250, 270, 290)
	self:AddRecipeFlags(13917, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE)
	self:AddRecipeAcquire(13917, A.TRAINER, 11073, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 16633, A.TRAINER, 11072, A.TRAINER, 1317, A.TRAINER, 3606, A.TRAINER, 4213, A.TRAINER, 16725, A.TRAINER, 3345, A.TRAINER, 3011, A.TRAINER, 11074, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 5695, A.TRAINER, 4616, A.TRAINER, 7949, A.TRAINER, 5157, A.TRAINER, 19540, A.TRAINER, 18753, A.TRAINER, 16160)

	-- Enchant Bracer - Deflection -- 13931
	AddRecipe(13931, 235, nil, Q.COMMON, V.ORIG, 235, 255, 275, 295)
	self:AddRecipeFlags(13931, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE, F.TANK)
	self:AddRecipeAcquire(13931, A.VENDOR, 989, A.VENDOR, 4229)

	-- Enchant Shield - Frost Resistance -- 13933 SPECIAL WORLD DROP
	AddRecipe(13933, 235, nil, Q.COMMON, V.ORIG, 235, 255, 275, 295)
	self:AddRecipeFlags(13933, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.SHIELD)
	self:AddRecipeAcquire(13933, A.WORLD_DROP, 2)

	-- Enchant Boots - Agility -- 13935
	AddRecipe(13935, 235, nil, Q.COMMON, V.ORIG, 235, 255, 275, 295)
	self:AddRecipeFlags(13935, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE, F.DPS)
	self:AddRecipeAcquire(13935, A.TRAINER, 11073, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 16633, A.TRAINER, 11072, A.TRAINER, 1317, A.TRAINER, 3606, A.TRAINER, 4213, A.TRAINER, 16725, A.TRAINER, 3345, A.TRAINER, 3011, A.TRAINER, 11074, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 5695, A.TRAINER, 4616, A.TRAINER, 7949, A.TRAINER, 5157, A.TRAINER, 19540, A.TRAINER, 18753, A.TRAINER, 16160)

	-- Enchant 2H Weapon - Greater Impact -- 13937
	AddRecipe(13937, 240, nil, Q.COMMON, V.ORIG, 240, 260, 280, 300)
	self:AddRecipeFlags(13937, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE, F.TWO_HAND)
	self:AddRecipeAcquire(13937, A.TRAINER, 1317, A.TRAINER, 3011, A.TRAINER, 3345, A.TRAINER, 3606, A.TRAINER, 4213, A.TRAINER, 4616, A.TRAINER, 5157, A.TRAINER, 5695, A.TRAINER, 11072, A.TRAINER, 11073, A.TRAINER, 11074, A.TRAINER, 16160, A.TRAINER, 16633, A.TRAINER, 16725, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 7949, A.TRAINER, 19540, A.TRAINER, 18753)

	-- Enchant Bracer - Greater Strength -- 13939
	AddRecipe(13939, 240, nil, Q.COMMON, V.ORIG, 240, 260, 280, 300)
	self:AddRecipeFlags(13939, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE, F.DPS)
	self:AddRecipeAcquire(13939, A.TRAINER, 11073, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 16633, A.TRAINER, 11072, A.TRAINER, 1317, A.TRAINER, 3606, A.TRAINER, 4213, A.TRAINER, 16725, A.TRAINER, 3345, A.TRAINER, 3011, A.TRAINER, 11074, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 5695, A.TRAINER, 4616, A.TRAINER, 7949, A.TRAINER, 5157, A.TRAINER, 19540, A.TRAINER, 18753, A.TRAINER, 16160)

	-- Enchant Chest - Stats -- 13941
	AddRecipe(13941, 245, nil, Q.COMMON, V.ORIG, 245, 265, 285, 305)
	self:AddRecipeFlags(13941, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE)
	self:AddRecipeAcquire(13941, A.TRAINER, 11073, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 16633, A.TRAINER, 11072, A.TRAINER, 1317, A.TRAINER, 3606, A.TRAINER, 4213, A.TRAINER, 16725, A.TRAINER, 3345, A.TRAINER, 3011, A.TRAINER, 11074, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 5695, A.TRAINER, 4616, A.TRAINER, 7949, A.TRAINER, 5157, A.TRAINER, 19540, A.TRAINER, 18753, A.TRAINER, 16160)

	-- Enchant Weapon - Greater Striking -- 13943
	AddRecipe(13943, 245, nil, Q.COMMON, V.ORIG, 245, 265, 285, 305)
	self:AddRecipeFlags(13943, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE, F.ONE_HAND, F.TWO_HAND)
	self:AddRecipeAcquire(13943, A.TRAINER, 11073, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 16633, A.TRAINER, 11072, A.TRAINER, 1317, A.TRAINER, 3606, A.TRAINER, 4213, A.TRAINER, 16725, A.TRAINER, 3345, A.TRAINER, 3011, A.TRAINER, 11074, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 5695, A.TRAINER, 4616, A.TRAINER, 7949, A.TRAINER, 5157, A.TRAINER, 19540, A.TRAINER, 18753, A.TRAINER, 16160)

	-- Enchant Bracer - Greater Stamina -- 13945
	AddRecipe(13945, 245, nil, Q.UNCOMMON, V.ORIG, 245, 265, 285, 305)
	self:AddRecipeFlags(13945, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE)
	self:AddRecipeAcquire(13945, A.WORLD_DROP, 2)

	-- Enchant Gloves - Riding Skill -- 13947
	AddRecipe(13947, 250, nil, Q.UNCOMMON, V.ORIG, 250, 270, 290, 310)
	self:AddRecipeFlags(13947, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE)
	self:AddRecipeAcquire(13947, A.WORLD_DROP, 2)

	-- Enchant Gloves - Minor Haste -- 13948
	AddRecipe(13948, 250, nil, Q.COMMON, V.ORIG, 250, 270, 290, 310)
	self:AddRecipeFlags(13948, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE)
	self:AddRecipeAcquire(13948, A.TRAINER, 11073, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 16633, A.TRAINER, 11072, A.TRAINER, 1317, A.TRAINER, 3606, A.TRAINER, 4213, A.TRAINER, 16725, A.TRAINER, 3345, A.TRAINER, 3011, A.TRAINER, 11074, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 5695, A.TRAINER, 4616, A.TRAINER, 7949, A.TRAINER, 5157, A.TRAINER, 19540, A.TRAINER, 18753, A.TRAINER, 16160)

	-- Lesser Magic Wand -- 14293
	AddRecipe(14293, 10, 11287, Q.COMMON, V.ORIG, 10, 75, 95, 115)
	self:AddRecipeFlags(14293, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.WAND)
	self:AddRecipeAcquire(14293, A.TRAINER, 1317, A.TRAINER, 3011, A.TRAINER, 3345, A.TRAINER, 3606, A.TRAINER, 4213, A.TRAINER, 4616, A.TRAINER, 5157, A.TRAINER, 5695, A.TRAINER, 11072, A.TRAINER, 11073, A.TRAINER, 11074, A.TRAINER, 16160, A.TRAINER, 16633, A.TRAINER, 16725, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 7949, A.TRAINER, 19540, A.TRAINER, 18753)

	-- Greater Magic Wand -- 14807
	AddRecipe(14807, 70, 11288, Q.COMMON, V.ORIG, 70, 110, 130, 150)
	self:AddRecipeFlags(14807, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.WAND)
	self:AddRecipeAcquire(14807, A.TRAINER, 1317, A.TRAINER, 3011, A.TRAINER, 3345, A.TRAINER, 3606, A.TRAINER, 4213, A.TRAINER, 4616, A.TRAINER, 5157, A.TRAINER, 5695, A.TRAINER, 11072, A.TRAINER, 11073, A.TRAINER, 11074, A.TRAINER, 16160, A.TRAINER, 16633, A.TRAINER, 16725, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 7949, A.TRAINER, 19540, A.TRAINER, 18753)

	-- Lesser Mystic Wand -- 14809
	AddRecipe(14809, 155, 11289, Q.COMMON, V.ORIG, 155, 175, 195, 215)
	self:AddRecipeFlags(14809, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.WAND)
	self:AddRecipeAcquire(14809, A.TRAINER, 11072, A.TRAINER, 11073, A.TRAINER, 11074, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 16633, A.TRAINER, 1317, A.TRAINER, 3606, A.TRAINER, 4213, A.TRAINER, 16725, A.TRAINER, 3345, A.TRAINER, 3011, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 5695, A.TRAINER, 4616, A.TRAINER, 7949, A.TRAINER, 5157, A.TRAINER, 19540, A.TRAINER, 18753, A.TRAINER, 16160)

	-- Greater Mystic Wand -- 14810
	AddRecipe(14810, 175, 11290, Q.COMMON, V.ORIG, 175, 195, 215, 235)
	self:AddRecipeFlags(14810, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.WAND)
	self:AddRecipeAcquire(14810, A.TRAINER, 11072, A.TRAINER, 11073, A.TRAINER, 11074, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 16633, A.TRAINER, 1317, A.TRAINER, 3606, A.TRAINER, 4213, A.TRAINER, 16725, A.TRAINER, 3345, A.TRAINER, 3011, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 5695, A.TRAINER, 4616, A.TRAINER, 7949, A.TRAINER, 5157, A.TRAINER, 19540, A.TRAINER, 18753, A.TRAINER, 16160)

	-- Smoking Heart of the Mountain -- 15596
	AddRecipe(15596, 265, 45050, Q.UNCOMMON, V.ORIG, 265, 285, 305, 325)
	self:AddRecipeFlags(15596, F.ALLIANCE, F.HORDE, F.INSTANCE, F.MOB_DROP, F.IBOP, F.RBOP, F.TRINKET)
	self:AddRecipeAcquire(15596, A.MOB, 9025)

	-- Enchanted Thorium -- 17180
	AddRecipe(17180, 250, 12655, Q.COMMON, V.ORIG, 250, 250, 255, 260)
	self:AddRecipeFlags(17180, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:AddRecipeAcquire(17180, A.TRAINER, 11073, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 16633, A.TRAINER, 11072, A.TRAINER, 1317, A.TRAINER, 3606, A.TRAINER, 4213, A.TRAINER, 16725, A.TRAINER, 3345, A.TRAINER, 3011, A.TRAINER, 11074, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 5695, A.TRAINER, 4616, A.TRAINER, 7949, A.TRAINER, 5157, A.TRAINER, 19540, A.TRAINER, 18753, A.TRAINER, 16160)

	-- Enchanted Leather -- 17181
	AddRecipe(17181, 250, 12810, Q.COMMON, V.ORIG, 250, 250, 255, 260)
	self:AddRecipeFlags(17181, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.LEATHER)
	self:AddRecipeAcquire(17181, A.TRAINER, 11073, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 16633, A.TRAINER, 11072, A.TRAINER, 1317, A.TRAINER, 3606, A.TRAINER, 4213, A.TRAINER, 16725, A.TRAINER, 3345, A.TRAINER, 3011, A.TRAINER, 11074, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 5695, A.TRAINER, 4616, A.TRAINER, 7949, A.TRAINER, 5157, A.TRAINER, 19540, A.TRAINER, 18753, A.TRAINER, 16160)

	-- Enchant Bracer - Greater Intellect -- 20008
	AddRecipe(20008, 255, nil, Q.COMMON, V.ORIG, 255, 275, 295, 315)
	self:AddRecipeFlags(20008, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE)
	self:AddRecipeAcquire(20008, A.TRAINER, 11073, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 16633, A.TRAINER, 11072, A.TRAINER, 1317, A.TRAINER, 3606, A.TRAINER, 4213, A.TRAINER, 16725, A.TRAINER, 3345, A.TRAINER, 3011, A.TRAINER, 11074, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 5695, A.TRAINER, 4616, A.TRAINER, 7949, A.TRAINER, 5157, A.TRAINER, 19540, A.TRAINER, 18753, A.TRAINER, 16160)

	-- Enchant Bracer - Superior Spirit -- 20009
	AddRecipe(20009, 270, nil, Q.UNCOMMON, V.ORIG, 270, 290, 310, 330)
	self:AddRecipeFlags(20009, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.HEALER, F.CASTER)
	self:AddRecipeAcquire(20009, A.WORLD_DROP, 2)

	-- Enchant Bracer - Superior Strength -- 20010
	AddRecipe(20010, 295, nil, Q.COMMON, V.ORIG, 295, 310, 325, 340)
	self:AddRecipeFlags(20010, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOE, F.DPS)
	self:AddRecipeAcquire(20010, A.MOB, 7372)

	-- Enchant Bracer - Superior Stamina -- 20011
	AddRecipe(20011, 300, nil, Q.UNCOMMON, V.ORIG, 300, 310, 325, 340)
	self:AddRecipeFlags(20011, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE)
	self:AddRecipeAcquire(20011, A.WORLD_DROP, 2)

	-- Enchant Gloves - Greater Agility -- 20012
	AddRecipe(20012, 270, nil, Q.COMMON, V.ORIG, 270, 290, 310, 330)
	self:AddRecipeFlags(20012, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE, F.DPS)
	self:AddRecipeAcquire(20012, A.TRAINER, 11073, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 16633, A.TRAINER, 11072, A.TRAINER, 1317, A.TRAINER, 3606, A.TRAINER, 4213, A.TRAINER, 16725, A.TRAINER, 3345, A.TRAINER, 3011, A.TRAINER, 11074, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 5695, A.TRAINER, 4616, A.TRAINER, 7949, A.TRAINER, 5157, A.TRAINER, 19540, A.TRAINER, 18753, A.TRAINER, 16160)

	-- Enchant Gloves - Greater Strength -- 20013
	AddRecipe(20013, 295, nil, Q.COMMON, V.ORIG, 295, 310, 325, 340)
	self:AddRecipeFlags(20013, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE, F.DPS)
	self:AddRecipeAcquire(20013, A.TRAINER, 11073, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 16633, A.TRAINER, 11072, A.TRAINER, 1317, A.TRAINER, 4213, A.TRAINER, 16725, A.TRAINER, 3345, A.TRAINER, 3011, A.TRAINER, 3606, A.TRAINER, 11074, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 5695, A.TRAINER, 4616, A.TRAINER, 7949, A.TRAINER, 5157, A.TRAINER, 19540, A.TRAINER, 18753, A.TRAINER, 16160)

	-- Enchant Cloak - Greater Resistance -- 20014
	AddRecipe(20014, 265, nil, Q.COMMON, V.ORIG, 265, 285, 305, 325)
	self:AddRecipeFlags(20014, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE, F.CLOAK)
	self:AddRecipeAcquire(20014, A.TRAINER, 11073, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 16633, A.TRAINER, 11072, A.TRAINER, 1317, A.TRAINER, 3606, A.TRAINER, 4213, A.TRAINER, 16725, A.TRAINER, 3345, A.TRAINER, 3011, A.TRAINER, 11074, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 5695, A.TRAINER, 4616, A.TRAINER, 7949, A.TRAINER, 5157, A.TRAINER, 19540, A.TRAINER, 18753, A.TRAINER, 16160)

	-- Enchant Cloak - Superior Defense -- 20015
	AddRecipe(20015, 285, nil, Q.COMMON, V.ORIG, 285, 300, 317, 335)
	self:AddRecipeFlags(20015, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.TANK, F.CLOAK)
	self:AddRecipeAcquire(20015, A.VENDOR, 12022)

	-- Enchant Shield - Vitality -- 20016
	AddRecipe(20016, 280, nil, Q.COMMON, V.ORIG, 280, 300, 320, 340)
	self:AddRecipeFlags(20016, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.SHIELD)
	self:AddRecipeAcquire(20016, A.TRAINER, 11073, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 16633, A.TRAINER, 11072, A.TRAINER, 1317, A.TRAINER, 3606, A.TRAINER, 4213, A.TRAINER, 16725, A.TRAINER, 3345, A.TRAINER, 3011, A.TRAINER, 11074, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 5695, A.TRAINER, 4616, A.TRAINER, 7949, A.TRAINER, 5157, A.TRAINER, 19540, A.TRAINER, 18753, A.TRAINER, 16160)

	-- Enchant Shield - Greater Stamina -- 20017
	AddRecipe(20017, 265, nil, Q.COMMON, V.ORIG, 265, 285, 305, 325)
	self:AddRecipeFlags(20017, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.SHIELD)
	self:AddRecipeAcquire(20017, A.VENDOR, 4229, A.VENDOR, 4561)

	-- Enchant Boots - Greater Stamina -- 20020
	AddRecipe(20020, 260, nil, Q.UNCOMMON, V.ORIG, 260, 280, 300, 320)
	self:AddRecipeFlags(20020, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE)
	self:AddRecipeAcquire(20020, A.WORLD_DROP, 2)

	-- Enchant Boots - Greater Agility -- 20023
	AddRecipe(20023, 295, nil, Q.COMMON, V.ORIG, 295, 310, 325, 340)
	self:AddRecipeFlags(20023, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE, F.DPS)
	self:AddRecipeAcquire(20023, A.TRAINER, 11073, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 16633, A.TRAINER, 11072, A.TRAINER, 1317, A.TRAINER, 3606, A.TRAINER, 4213, A.TRAINER, 16725, A.TRAINER, 3345, A.TRAINER, 3011, A.TRAINER, 11074, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 5695, A.TRAINER, 4616, A.TRAINER, 7949, A.TRAINER, 5157, A.TRAINER, 19540, A.TRAINER, 18753, A.TRAINER, 16160)

	-- Enchant Boots - Spirit -- 20024
	AddRecipe(20024, 275, nil, Q.UNCOMMON, V.ORIG, 275, 295, 315, 335)
	self:AddRecipeFlags(20024, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.HEALER, F.CASTER)
	self:AddRecipeAcquire(20024, A.WORLD_DROP, 2)

	-- Enchant Chest - Greater Stats -- 20025
	AddRecipe(20025, 300, nil, Q.UNCOMMON, V.ORIG, 300, 310, 325, 340)
	self:AddRecipeFlags(20025, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE)
	self:AddRecipeAcquire(20025, A.WORLD_DROP, 2)

	-- Enchant Chest - Major Health -- 20026
	AddRecipe(20026, 275, nil, Q.COMMON, V.ORIG, 275, 295, 315, 335)
	self:AddRecipeFlags(20026, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP)
	self:AddRecipeAcquire(20026, A.VENDOR, 11189)

	-- Enchant Chest - Major Mana -- 20028
	AddRecipe(20028, 290, nil, Q.COMMON, V.ORIG, 290, 305, 322, 340)
	self:AddRecipeFlags(20028, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE)
	self:AddRecipeAcquire(20028, A.TRAINER, 11073, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 16633, A.TRAINER, 11072, A.TRAINER, 1317, A.TRAINER, 3606, A.TRAINER, 4213, A.TRAINER, 16725, A.TRAINER, 3345, A.TRAINER, 3011, A.TRAINER, 11074, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 5695, A.TRAINER, 4616, A.TRAINER, 7949, A.TRAINER, 5157, A.TRAINER, 19540, A.TRAINER, 18753, A.TRAINER, 16160)

	-- Enchant Weapon - Icy Chill -- 20029
	AddRecipe(20029, 285, nil, Q.COMMON, V.ORIG, 285, 300, 317, 335)
	self:AddRecipeFlags(20029, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOE, F.ONE_HAND, F.TWO_HAND)
	self:AddRecipeAcquire(20029, A.MOB, 7524)

	-- Enchant 2H Weapon - Superior Impact -- 20030
	AddRecipe(20030, 295, nil, Q.COMMON, V.ORIG, 295, 310, 325, 340)
	self:AddRecipeFlags(20030, F.ALLIANCE, F.HORDE, F.INSTANCE, F.IBOE, F.RBOE, F.TWO_HAND)
	self:AddRecipeAcquire(20030, A.MOB, 10317)

	-- Enchant Weapon - Superior Striking -- 20031
	AddRecipe(20031, 300, nil, Q.COMMON, V.ORIG, 300, 310, 325, 340)
	self:AddRecipeFlags(20031, F.ALLIANCE, F.HORDE, F.INSTANCE, F.IBOE, F.RBOE, F.ONE_HAND, F.TWO_HAND)
	self:AddRecipeAcquire(20031, A.MOB, 9216)

	-- Enchant Weapon - Lifestealing -- 20032
	AddRecipe(20032, 300, nil, Q.RARE, V.ORIG, 300, 310, 325, 340)
	self:AddRecipeFlags(20032, F.ALLIANCE, F.HORDE, F.INSTANCE, F.IBOE, F.RBOE, F.ONE_HAND, F.TWO_HAND)
	self:AddRecipeAcquire(20032, A.MOB, 10499)

	-- Enchant Weapon - Unholy Weapon -- 20033
	AddRecipe(20033, 295, nil, Q.COMMON, V.ORIG, 295, 310, 325, 340)
	self:AddRecipeFlags(20033, F.ALLIANCE, F.HORDE, F.INSTANCE, F.MOB_DROP, F.IBOE, F.RBOE, F.ONE_HAND, F.TWO_HAND)
	self:AddRecipeAcquire(20033, A.MOB, 10398, A.MOB, 16810)

	-- Enchant Weapon - Crusader -- 20034
	AddRecipe(20034, 300, nil, Q.COMMON, V.ORIG, 300, 310, 325, 340)
	self:AddRecipeFlags(20034, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOE, F.DPS, F.ONE_HAND, F.TWO_HAND)
	self:AddRecipeAcquire(20034, A.MOB, 4494, A.MOB, 9451)

	-- Enchant 2H Weapon - Major Spirit -- 20035
	AddRecipe(20035, 300, nil, Q.COMMON, V.ORIG, 300, 310, 325, 340)
	self:AddRecipeFlags(20035, F.ALLIANCE, F.HORDE, F.INSTANCE, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.TWO_HAND)
	self:AddRecipeAcquire(20035, A.MOB, 10469)

	-- Enchant 2H Weapon - Major Intellect -- 20036
	AddRecipe(20036, 300, nil, Q.COMMON, V.ORIG, 300, 310, 325, 340)
	self:AddRecipeFlags(20036, F.ALLIANCE, F.HORDE, F.INSTANCE, F.IBOE, F.RBOE, F.TWO_HAND)
	self:AddRecipeAcquire(20036, A.MOB, 10422)

	-- Runed Arcanite Rod -- 20051
	AddRecipe(20051, 290, 16207, Q.COMMON, V.ORIG, 290, 305, 322, 340)
	self:AddRecipeFlags(20051, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOP, F.RBOP)
	self:AddRecipeAcquire(20051, A.VENDOR, 12022)

	-- Enchant Weapon - Winter's Might -- 21931
	AddRecipe(21931, 190, nil, Q.UNCOMMON, V.ORIG, 190, 210, 230, 250)
	self:AddRecipeFlags(21931, F.ALLIANCE, F.HORDE, F.SEASONAL, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.ONE_HAND, F.TWO_HAND)
	self:AddRecipeAcquire(21931, A.SEASONAL, 1)

	-- Enchant Weapon - Spellpower -- 22749
	AddRecipe(22749, 300, nil, Q.RARE, V.ORIG, 300, 310, 325, 340)
	self:AddRecipeFlags(22749, F.ALLIANCE, F.HORDE, F.RAID, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.ONE_HAND, F.TWO_HAND)
	self:AddRecipeAcquire(22749, A.CUSTOM, 26)

	-- Enchant Weapon - Healing Power -- 22750
	AddRecipe(22750, 300, nil, Q.RARE, V.ORIG, 300, 310, 325, 340)
	self:AddRecipeFlags(22750, F.ALLIANCE, F.HORDE, F.RAID, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.ONE_HAND, F.TWO_HAND)
	self:AddRecipeAcquire(22750, A.CUSTOM, 26)

	-- Enchant Weapon - Strength -- 23799
	AddRecipe(23799, 290, nil, Q.COMMON, V.ORIG, 290, 305, 322, 340)
	self:AddRecipeFlags(23799, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE, F.DPS, F.ONE_HAND, F.TWO_HAND, F.THORIUM_BROTHERHOOD)
	self:AddRecipeAcquire(23799, A.REPUTATION, FAC.THORIUM_BROTHERHOOD, REP.FRIENDLY, 12944)

	-- Enchant Weapon - Agility -- 23800
	AddRecipe(23800, 290, nil, Q.COMMON, V.ORIG, 290, 305, 322, 340)
	self:AddRecipeFlags(23800, F.HORDE, F.VENDOR, F.IBOE, F.RBOE, F.DPS, F.ONE_HAND, F.TWO_HAND, F.TIMBERMAW_HOLD)
	self:AddRecipeAcquire(23800, A.REPUTATION, FAC.TIMBERMAW_HOLD, REP.HONORED, 11557)

	-- Enchant Bracer - Mana Regeneration -- 23801
	AddRecipe(23801, 290, nil, Q.COMMON, V.ORIG, 290, 305, 322, 340)
	self:AddRecipeFlags(23801, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.ARGENTDAWN)
	self:AddRecipeAcquire(23801, A.REPUTATION, FAC.ARGENTDAWN, REP.HONORED, 10856, A.REPUTATION, FAC.ARGENTDAWN, REP.HONORED, 10857, A.REPUTATION, FAC.ARGENTDAWN, REP.HONORED, 11536)

	-- Enchant Bracer - Healing Power -- 23802
	AddRecipe(23802, 300, nil, Q.COMMON, V.ORIG, 300, 310, 325, 340)
	self:AddRecipeFlags(23802, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.ARGENTDAWN)
	self:AddRecipeAcquire(23802, A.REPUTATION, FAC.ARGENTDAWN, REP.REVERED, 10856, A.REPUTATION, FAC.ARGENTDAWN, REP.REVERED, 10857, A.REPUTATION, FAC.ARGENTDAWN, REP.REVERED, 11536)

	-- Enchant Weapon - Mighty Spirit -- 23803
	AddRecipe(23803, 300, nil, Q.COMMON, V.ORIG, 300, 310, 325, 340)
	self:AddRecipeFlags(23803, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.ONE_HAND, F.TWO_HAND, F.THORIUM_BROTHERHOOD)
	self:AddRecipeAcquire(23803, A.REPUTATION, FAC.THORIUM_BROTHERHOOD, REP.HONORED, 12944)

	-- Enchant Weapon - Mighty Intellect -- 23804
	AddRecipe(23804, 300, nil, Q.COMMON, V.ORIG, 300, 310, 325, 340)
	self:AddRecipeFlags(23804, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.ONE_HAND, F.TWO_HAND, F.THORIUM_BROTHERHOOD)
	self:AddRecipeAcquire(23804, A.REPUTATION, FAC.THORIUM_BROTHERHOOD, REP.REVERED, 12944)

	-- Enchant Gloves - Threat -- 25072
	AddRecipe(25072, 300, nil, Q.RARE, V.ORIG, 300, 310, 325, 340)
	self:AddRecipeFlags(25072, F.ALLIANCE, F.HORDE, F.VENDOR, F.RAID, F.MOB_DROP, F.IBOE, F.RBOE, F.TANK, F.SHATAR)
	self:AddRecipeAcquire(25072, A.MOB, 15275, A.REPUTATION, FAC.SHATAR, REP.EXALTED, 21432)

	-- Enchant Gloves - Shadow Power -- 25073
	AddRecipe(25073, 300, nil, Q.RARE, V.ORIG, 300, 310, 325, 340)
	self:AddRecipeFlags(25073, F.ALLIANCE, F.HORDE, F.RAID, F.IBOE, F.RBOE, F.HEALER, F.CASTER)
	self:AddRecipeAcquire(25073, A.CUSTOM, 22)

	-- Enchant Gloves - Frost Power -- 25074
	AddRecipe(25074, 300, nil, Q.RARE, V.ORIG, 300, 310, 325, 340)
	self:AddRecipeFlags(25074, F.ALLIANCE, F.HORDE, F.RAID, F.IBOE, F.RBOE, F.HEALER, F.CASTER)
	self:AddRecipeAcquire(25074, A.CUSTOM, 22)

	-- Enchant Gloves - Fire Power -- 25078
	AddRecipe(25078, 300, nil, Q.RARE, V.ORIG, 300, 310, 325, 340)
	self:AddRecipeFlags(25078, F.ALLIANCE, F.HORDE, F.RAID, F.IBOE, F.RBOE, F.HEALER, F.CASTER)
	self:AddRecipeAcquire(25078, A.CUSTOM, 22)

	-- Enchant Gloves - Healing Power -- 25079
	AddRecipe(25079, 300, nil, Q.RARE, V.ORIG, 300, 310, 325, 340)
	self:AddRecipeFlags(25079, F.ALLIANCE, F.HORDE, F.RAID, F.IBOE, F.RBOE, F.HEALER, F.CASTER)
	self:AddRecipeAcquire(25079, A.CUSTOM, 22)

	-- Enchant Gloves - Superior Agility -- 25080
	AddRecipe(25080, 300, nil, Q.RARE, V.TBC, 300, 310, 325, 340)
	self:AddRecipeFlags(25080, F.ALLIANCE, F.HORDE, F.VENDOR, F.RAID, F.IBOE, F.RBOE, F.DPS, F.KOT)
	self:AddRecipeAcquire(25080, A.CUSTOM, 22, A.REPUTATION, FAC.KEEPERS_OF_TIME, REP.EXALTED, 21643)

	-- Enchant Cloak - Greater Fire Resistance -- 25081
	AddRecipe(25081, 300, nil, Q.COMMON, V.ORIG, 300, 310, 325, 340)
	self:AddRecipeFlags(25081, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE, F.CLOAK, F.CENARION_CIRCLE)
	self:AddRecipeAcquire(25081, A.REPUTATION, FAC.CENARION_CIRCLE, REP.FRIENDLY, 15419)

	-- Enchant Cloak - Greater Nature Resistance -- 25082
	AddRecipe(25082, 300, nil, Q.COMMON, V.ORIG, 300, 310, 325, 340)
	self:AddRecipeFlags(25082, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE, F.CLOAK, F.CENARION_CIRCLE)
	self:AddRecipeAcquire(25082, A.REPUTATION, FAC.CENARION_CIRCLE, REP.HONORED, 15419)

	-- Enchant Cloak - Stealth -- 25083
	AddRecipe(25083, 300, nil, Q.RARE, V.TBC, 300, 310, 325, 340)
	self:AddRecipeFlags(25083, F.ALLIANCE, F.HORDE, F.VENDOR, F.RAID, F.IBOE, F.RBOE, F.CLOAK, F.CENARION_EXPEDITION)
	self:AddRecipeAcquire(25083, A.CUSTOM, 22, A.REPUTATION, FAC.CENARION_EXPEDITION, REP.EXALTED, 17904)

	-- Enchant Cloak - Subtlety -- 25084
	AddRecipe(25084, 300, nil, Q.RARE, V.TBC, 300, 310, 325, 340)
	self:AddRecipeFlags(25084, F.ALLIANCE, F.HORDE, F.VENDOR, F.RAID, F.IBOE, F.RBOE, F.CLOAK, F.HELLFIRE)
	self:AddRecipeAcquire(25084, A.MOB, 15276, A.REPUTATION, FAC.HONOR_HOLD, REP.EXALTED, 17657, A.REPUTATION, FAC.THRALLMAR, REP.EXALTED, 17585)

	-- Enchant Cloak - Dodge -- 25086
	AddRecipe(25086, 300, nil, Q.RARE, V.TBC, 300, 310, 325, 340)
	self:AddRecipeFlags(25086, F.ALLIANCE, F.HORDE, F.VENDOR, F.RAID, F.IBOE, F.RBOE, F.TANK, F.CLOAK, F.LOWERCITY)
	self:AddRecipeAcquire(25086, A.CUSTOM, 22, A.REPUTATION, FAC.LOWERCITY, REP.EXALTED, 21655)

	-- Minor Wizard Oil -- 25124
	AddRecipe(25124, 45, 20744, Q.COMMON, V.ORIG, 45, 55, 65, 75)
	self:AddRecipeFlags(25124, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE, F.HEALER, F.CASTER)
	self:AddRecipeAcquire(25124, A.VENDOR, 1318, A.VENDOR, 3012, A.VENDOR, 3346, A.VENDOR, 4228, A.VENDOR, 4617, A.VENDOR, 5158, A.VENDOR, 5757, A.VENDOR, 5758, A.VENDOR, 15419, A.VENDOR, 16635, A.VENDOR, 16722, A.VENDOR, 18753, A.VENDOR, 18773, A.VENDOR, 18951, A.VENDOR, 19234, A.VENDOR, 19537, A.VENDOR, 19540, A.VENDOR, 19663, A.VENDOR, 26569, A.VENDOR, 27030, A.VENDOR, 27054, A.VENDOR, 27147, A.VENDOR, 28714)

	-- Minor Mana Oil -- 25125
	AddRecipe(25125, 150, 20745, Q.COMMON, V.ORIG, 150, 160, 170, 180)
	self:AddRecipeFlags(25125, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE)
	self:AddRecipeAcquire(25125, A.VENDOR, 1318, A.VENDOR, 3012, A.VENDOR, 3346, A.VENDOR, 4228, A.VENDOR, 4617, A.VENDOR, 5158, A.VENDOR, 5757, A.VENDOR, 5758, A.VENDOR, 15419, A.VENDOR, 16635, A.VENDOR, 16722, A.VENDOR, 18753, A.VENDOR, 18773, A.VENDOR, 18951, A.VENDOR, 19234, A.VENDOR, 19537, A.VENDOR, 19540, A.VENDOR, 19663, A.VENDOR, 26569, A.VENDOR, 27030, A.VENDOR, 27054, A.VENDOR, 27147, A.VENDOR, 28714)

	-- Lesser Wizard Oil -- 25126
	AddRecipe(25126, 200, 20746, Q.COMMON, V.ORIG, 200, 210, 220, 230)
	self:AddRecipeFlags(25126, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE, F.HEALER, F.CASTER)
	self:AddRecipeAcquire(25126, A.VENDOR, 1318, A.VENDOR, 3012, A.VENDOR, 3346, A.VENDOR, 4228, A.VENDOR, 4617, A.VENDOR, 5158, A.VENDOR, 5757, A.VENDOR, 5758, A.VENDOR, 15419, A.VENDOR, 16635, A.VENDOR, 16722, A.VENDOR, 18753, A.VENDOR, 18773, A.VENDOR, 18951, A.VENDOR, 19234, A.VENDOR, 19537, A.VENDOR, 19540, A.VENDOR, 19663, A.VENDOR, 26569, A.VENDOR, 27030, A.VENDOR, 27054, A.VENDOR, 27147, A.VENDOR, 28714)

	-- Lesser Mana Oil -- 25127
	AddRecipe(25127, 250, 20747, Q.COMMON, V.ORIG, 250, 260, 270, 280)
	self:AddRecipeFlags(25127, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE)
	self:AddRecipeAcquire(25127, A.VENDOR, 15419)

	-- Wizard Oil -- 25128
	AddRecipe(25128, 275, 20750, Q.COMMON, V.ORIG, 275, 285, 295, 305)
	self:AddRecipeFlags(25128, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE, F.HEALER, F.CASTER)
	self:AddRecipeAcquire(25128, A.VENDOR, 15419)

	-- Brilliant Wizard Oil -- 25129
	AddRecipe(25129, 300, 20749, Q.COMMON, V.ORIG, 300, 310, 320, 330)
	self:AddRecipeFlags(25129, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.ZANDALAR)
	self:AddRecipeAcquire(25129, A.REPUTATION, FAC.ZANDALAR, REP.HONORED, 14921)

	-- Brilliant Mana Oil -- 25130
	AddRecipe(25130, 300, 20748, Q.COMMON, V.ORIG, 300, 310, 320, 330)
	self:AddRecipeFlags(25130, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.ZANDALAR)
	self:AddRecipeAcquire(25130, A.REPUTATION, FAC.ZANDALAR, REP.FRIENDLY, 14921)

	-- Enchant 2H Weapon - Agility -- 27837
	AddRecipe(27837, 290, nil, Q.COMMON, V.ORIG, 290, 305, 322, 340)
	self:AddRecipeFlags(27837, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE, F.DPS, F.TWO_HAND, F.TIMBERMAW_HOLD)
	self:AddRecipeAcquire(27837, A.REPUTATION, FAC.TIMBERMAW_HOLD, REP.FRIENDLY, 11557)

	-- Enchant Bracer - Brawn -- 27899
	AddRecipe(27899, 305, nil, Q.COMMON, V.TBC, 305, 315, 330, 345)
	self:AddRecipeFlags(27899, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE, F.DPS)
	self:AddRecipeAcquire(27899, A.TRAINER, 18753, A.TRAINER, 18773, A.TRAINER, 19252, A.TRAINER, 19540, A.TRAINER, 33610, A.TRAINER, 33676)

	-- Enchant Bracer - Stats -- 27905
	AddRecipe(27905, 315, nil, Q.COMMON, V.TBC, 315, 325, 340, 355)
	self:AddRecipeFlags(27905, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE)
	self:AddRecipeAcquire(27905, A.TRAINER, 18753, A.TRAINER, 18773, A.TRAINER, 19252, A.TRAINER, 19540, A.TRAINER, 33610, A.TRAINER, 33676)

	-- Enchant Bracer - Major Defense -- 27906
	AddRecipe(27906, 320, nil, Q.COMMON, V.TBC, 320, 330, 345, 360)
	self:AddRecipeFlags(27906, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOE, F.TANK)
	self:AddRecipeAcquire(27906, A.MOB, 22822, A.MOB, 23008)

	-- Enchant Bracer - Superior Healing -- 27911
	AddRecipe(27911, 325, nil, Q.COMMON, V.TBC, 325, 335, 350, 365)
	self:AddRecipeFlags(27911, F.HORDE, F.VENDOR, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.HELLFIRE)
	self:AddRecipeAcquire(27911, A.REPUTATION, FAC.HONOR_HOLD, REP.FRIENDLY, 17657, A.REPUTATION, FAC.THRALLMAR, REP.FRIENDLY, 17585)

	-- Enchant Bracer - Restore Mana Prime -- 27913
	AddRecipe(27913, 335, nil, Q.UNCOMMON, V.TBC, 335, 345, 360, 375)
	self:AddRecipeFlags(27913, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.HEALER, F.CASTER)
	self:AddRecipeAcquire(27913, A.WORLD_DROP, 2)

	-- Enchant Bracer - Fortitude -- 27914
	AddRecipe(27914, 350, nil, Q.COMMON, V.TBC, 350, 370, 375, 380)
	self:AddRecipeFlags(27914, F.ALLIANCE, F.HORDE, F.INSTANCE, F.IBOE, F.RBOE)
	self:AddRecipeAcquire(27914, A.MOB, 17803)

	-- Enchant Bracer - Spellpower -- 27917
	AddRecipe(27917, 360, nil, Q.COMMON, V.TBC, 360, 370, 385, 400)
	self:AddRecipeFlags(27917, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOE, F.HEALER, F.CASTER)
	self:AddRecipeAcquire(27917, A.MOB, 19952)

	-- Enchant Ring - Striking -- 27920
	AddRecipe(27920, 360, nil, Q.COMMON, V.TBC, 360, 370, 377, 385)
	self:AddRecipeFlags(27920, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.RING, F.CONSORTIUM)
	self:AddRecipeAcquire(27920, A.REPUTATION, FAC.CONSORTIUM, REP.REVERED, 17518)

	-- Enchant Ring - Spellpower -- 27924
	AddRecipe(27924, 360, nil, Q.COMMON, V.TBC, 360, 370, 377, 385)
	self:AddRecipeFlags(27924, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.RING, F.KOT)
	self:AddRecipeAcquire(27924, A.REPUTATION, FAC.KEEPERS_OF_TIME, REP.HONORED, 21643)

	-- Enchant Ring - Healing Power -- 27926
	AddRecipe(27926, 370, nil, Q.COMMON, V.TBC, 370, 380, 385, 390)
	self:AddRecipeFlags(27926, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOP, F.RBOP, F.HEALER, F.CASTER, F.RING, F.SHATAR)
	self:AddRecipeAcquire(27926, A.REPUTATION, FAC.SHATAR, REP.REVERED, 21432)

	-- Enchant Ring - Stats -- 27927
	AddRecipe(27927, 375, nil, Q.COMMON, V.TBC, 375, 380, 385, 390)
	self:AddRecipeFlags(27927, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.RING, F.LOWERCITY)
	self:AddRecipeAcquire(27927, A.REPUTATION, FAC.LOWERCITY, REP.HONORED, 21655)

	-- Enchant Shield - Tough Shield -- 27944
	AddRecipe(27944, 310, nil, Q.COMMON, V.TBC, 310, 320, 335, 350)
	self:AddRecipeFlags(27944, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE, F.TANK, F.SHIELD)
	self:AddRecipeAcquire(27944, A.TRAINER, 18753, A.TRAINER, 18773, A.TRAINER, 19252, A.TRAINER, 19540, A.TRAINER, 33610, A.TRAINER, 33676)

	-- Enchant Shield - Intellect -- 27945
	AddRecipe(27945, 325, nil, Q.COMMON, V.TBC, 325, 335, 350, 365)
	self:AddRecipeFlags(27945, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE, F.SHIELD)
	self:AddRecipeAcquire(27945, A.VENDOR, 18664)

	-- Enchant Shield - Shield Block -- 27946
	AddRecipe(27946, 340, nil, Q.UNCOMMON, V.TBC, 340, 350, 365, 380)
	self:AddRecipeFlags(27946, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.TANK, F.SHIELD)
	self:AddRecipeAcquire(27946, A.WORLD_DROP, 2)

	-- Enchant Shield - Resistance -- 27947
	AddRecipe(27947, 360, nil, Q.UNCOMMON, V.TBC, 360, 370, 375, 380)
	self:AddRecipeFlags(27947, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.SHIELD)
	self:AddRecipeAcquire(27947, A.WORLD_DROP, 2)

	-- Enchant Boots - Vitality -- 27948
	AddRecipe(27948, 305, nil, Q.COMMON, V.TBC, 305, 315, 330, 345)
	self:AddRecipeFlags(27948, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOE, F.HEALER, F.CASTER)
	self:AddRecipeAcquire(27948, A.MOB, 24664)

	-- Enchant Boots - Fortitude -- 27950
	AddRecipe(27950, 320, nil, Q.COMMON, V.TBC, 320, 330, 345, 360)
	self:AddRecipeFlags(27950, F.ALLIANCE, F.HORDE, F.INSTANCE, F.MOB_DROP, F.IBOE, F.RBOE)
	self:AddRecipeAcquire(27950, A.MOB, 18317)

	-- Enchant Boots - Dexterity -- 27951
	AddRecipe(27951, 340, nil, Q.COMMON, V.TBC, 340, 350, 365, 380)
	self:AddRecipeFlags(27951, F.ALLIANCE, F.HORDE, F.INSTANCE, F.IBOE, F.RBOE, F.DPS)
	self:AddRecipeAcquire(27951, A.MOB, 18521)

	-- Enchant Boots - Surefooted -- 27954
	AddRecipe(27954, 370, nil, Q.COMMON, V.TBC, 370, 380, 385, 390)
	self:AddRecipeFlags(27954, F.ALLIANCE, F.HORDE, F.RAID, F.IBOE, F.RBOP, F.DPS, F.CASTER)
	self:AddRecipeAcquire(27954, A.MOB, 16472)

	-- Enchant Chest - Exceptional Health -- 27957
	AddRecipe(27957, 315, nil, Q.COMMON, V.TBC, 315, 325, 340, 355)
	self:AddRecipeFlags(27957, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE)
	self:AddRecipeAcquire(27957, A.TRAINER, 18753, A.TRAINER, 18773, A.TRAINER, 19252, A.TRAINER, 19540, A.TRAINER, 33610, A.TRAINER, 33676)

	-- Enchant Chest - Exceptional Mana -- 27958
	AddRecipe(27958, 350, nil, Q.COMMON, V.WOTLK, 350, 360, 370, 380)
	self:AddRecipeFlags(27958, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:AddRecipeAcquire(27958, A.TRAINER, 28693, A.TRAINER, 33583, A.TRAINER, 26990, A.TRAINER, 26980, A.TRAINER, 26954, A.TRAINER, 26906)

	-- Enchant Chest - Exceptional Stats -- 27960
	AddRecipe(27960, 345, nil, Q.COMMON, V.TBC, 345, 355, 367, 380)
	self:AddRecipeFlags(27960, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE, F.HELLFIRE)
	self:AddRecipeAcquire(27960, A.REPUTATION, FAC.HONOR_HOLD, REP.REVERED, 17657, A.REPUTATION, FAC.THRALLMAR, REP.REVERED, 17585)

	-- Enchant Cloak - Major Armor -- 27961
	AddRecipe(27961, 310, nil, Q.COMMON, V.TBC, 310, 320, 335, 350)
	self:AddRecipeFlags(27961, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE, F.CLOAK)
	self:AddRecipeAcquire(27961, A.TRAINER, 18753, A.TRAINER, 18773, A.TRAINER, 19252, A.TRAINER, 19540, A.TRAINER, 33610, A.TRAINER, 33676)

	-- Enchant Cloak - Major Resistance -- 27962
	AddRecipe(27962, 330, nil, Q.UNCOMMON, V.TBC, 330, 340, 355, 370)
	self:AddRecipeFlags(27962, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.CLOAK)
	self:AddRecipeAcquire(27962, A.WORLD_DROP, 2)

	-- Enchant Weapon - Major Striking -- 27967
	AddRecipe(27967, 340, nil, Q.COMMON, V.TBC, 340, 350, 365, 380)
	self:AddRecipeFlags(27967, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE, F.ONE_HAND, F.TWO_HAND, F.CONSORTIUM)
	self:AddRecipeAcquire(27967, A.REPUTATION, FAC.CONSORTIUM, REP.HONORED, 20242, A.REPUTATION, FAC.CONSORTIUM, REP.HONORED, 23007)

	-- Enchant Weapon - Major Intellect -- 27968
	AddRecipe(27968, 340, nil, Q.COMMON, V.TBC, 340, 350, 365, 380)
	self:AddRecipeFlags(27968, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOE, F.ONE_HAND, F.TWO_HAND)
	self:AddRecipeAcquire(27968, A.MOB, 20136)

	-- Enchant 2H Weapon - Savagery -- 27971
	AddRecipe(27971, 350, nil, Q.COMMON, V.TBC, 350, 370, 375, 380)
	self:AddRecipeFlags(27971, F.ALLIANCE, F.HORDE, F.INSTANCE, F.IBOE, F.RBOE, F.DPS, F.TWO_HAND)
	self:AddRecipeAcquire(27971, A.MOB, 17465)

	-- Enchant Weapon - Potency -- 27972
	AddRecipe(27972, 350, nil, Q.UNCOMMON, V.TBC, 350, 370, 375, 380)
	self:AddRecipeFlags(27972, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.DPS, F.ONE_HAND, F.TWO_HAND)
	self:AddRecipeAcquire(27972, A.WORLD_DROP, 2)

	-- Enchant Weapon - Major Spellpower -- 27975
	AddRecipe(27975, 350, nil, Q.COMMON, V.TBC, 350, 370, 375, 380)
	self:AddRecipeFlags(27975, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.ONE_HAND, F.TWO_HAND)
	self:AddRecipeAcquire(27975, A.MOB, 22242)

	-- Enchant 2H Weapon - Major Agility -- 27977
	AddRecipe(27977, 360, nil, Q.COMMON, V.TBC, 360, 370, 377, 385)
	self:AddRecipeFlags(27977, F.ALLIANCE, F.HORDE, F.INSTANCE, F.IBOE, F.RBOE, F.DPS, F.TWO_HAND)
	self:AddRecipeAcquire(27977, A.MOB, 20880)

	-- Enchant Weapon - Sunfire -- 27981
	AddRecipe(27981, 375, nil, Q.RARE, V.TBC, 375, 375, 375, 390)
	self:AddRecipeFlags(27981, F.ALLIANCE, F.HORDE, F.RAID, F.MOB_DROP, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.ONE_HAND, F.TWO_HAND)
	self:AddRecipeAcquire(27981, A.MOB, 16524)

	-- Enchant Weapon - Soulfrost -- 27982
	AddRecipe(27982, 375, nil, Q.RARE, V.TBC, 375, 380, 385, 390)
	self:AddRecipeFlags(27982, F.ALLIANCE, F.HORDE, F.RAID, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.ONE_HAND, F.TWO_HAND)
	self:AddRecipeAcquire(27982, A.MOB, 15688)

	-- Enchant Weapon - Mongoose -- 27984
	AddRecipe(27984, 375, nil, Q.RARE, V.TBC, 375, 380, 385, 390)
	self:AddRecipeFlags(27984, F.ALLIANCE, F.HORDE, F.RAID, F.MOB_DROP, F.IBOE, F.RBOE, F.DPS, F.ONE_HAND, F.TWO_HAND)
	self:AddRecipeAcquire(27984, A.MOB, 15687)

	-- Enchant Weapon - Spellsurge -- 28003
	AddRecipe(28003, 360, nil, Q.COMMON, V.TBC, 360, 370, 377, 385)
	self:AddRecipeFlags(28003, F.ALLIANCE, F.HORDE, F.INSTANCE, F.RAID, F.IBOE, F.RBOE, F.ONE_HAND, F.TWO_HAND)
	self:AddRecipeAcquire(28003, A.WORLD_DROP, 2)

	-- Enchant Weapon - Battlemaster -- 28004
	AddRecipe(28004, 360, nil, Q.UNCOMMON, V.TBC, 360, 370, 377, 385)
	self:AddRecipeFlags(28004, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.ONE_HAND, F.TWO_HAND)
	self:AddRecipeAcquire(28004, A.WORLD_DROP, 2)

	-- Superior Mana Oil -- 28016
	AddRecipe(28016, 310, 22521, Q.COMMON, V.TBC, 310, 310, 320, 330)
	self:AddRecipeFlags(28016, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE)
	self:AddRecipeAcquire(28016, A.VENDOR, 16635, A.VENDOR, 16722, A.VENDOR, 19663)

	-- Superior Wizard Oil -- 28019
	AddRecipe(28019, 340, 22522, Q.COMMON, V.TBC, 340, 340, 350, 360)
	self:AddRecipeFlags(28019, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE, F.HEALER, F.CASTER)
	self:AddRecipeAcquire(28019, A.VENDOR, 16635, A.VENDOR, 16722, A.VENDOR, 19663)

	-- Large Prismatic Shard -- 28022
	AddRecipe(28022, 335, 22449, Q.COMMON, V.TBC, 335, 335, 335, 335)
	self:AddRecipeFlags(28022, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE)
	self:AddRecipeAcquire(28022, A.VENDOR, 16635, A.VENDOR, 16722, A.VENDOR, 19663)

	-- Prismatic Sphere -- 28027
	AddRecipe(28027, 325, 22460, Q.COMMON, V.TBC, 325, 325, 330, 335)
	self:AddRecipeFlags(28027, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:AddRecipeAcquire(28027, A.TRAINER, 18753, A.TRAINER, 18773, A.TRAINER, 19252, A.TRAINER, 19540, A.TRAINER, 33610, A.TRAINER, 33676)

	-- Void Sphere -- 28028
	AddRecipe(28028, 350, 22459, Q.COMMON, V.TBC, 350, 370, 375, 380)
	self:AddRecipeFlags(28028, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:AddRecipeAcquire(28028, A.TRAINER, 18753, A.TRAINER, 18773, A.TRAINER, 19252, A.TRAINER, 19540, A.TRAINER, 33610, A.TRAINER, 33676)

	-- Runed Fel Iron Rod -- 32664
	AddRecipe(32664, 300, 22461, Q.COMMON, V.TBC, 300, 310, 325, 340)
	self:AddRecipeFlags(32664, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOP, F.RBOP)
	self:AddRecipeAcquire(32664, A.TRAINER, 18753, A.TRAINER, 18773, A.TRAINER, 19252, A.TRAINER, 19540, A.TRAINER, 33610, A.TRAINER, 33676)

	-- Runed Adamantite Rod -- 32665
	AddRecipe(32665, 350, 22462, Q.COMMON, V.TBC, 350, 370, 375, 380)
	self:AddRecipeFlags(32665, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOP, F.RBOP)
	self:AddRecipeAcquire(32665, A.VENDOR, 18960, A.VENDOR, 19004)

	-- Runed Eternium Rod -- 32667
	AddRecipe(32667, 375, 22463, Q.COMMON, V.TBC, 375, 375, 377, 385)
	self:AddRecipeFlags(32667, F.ALLIANCE, F.HORDE, F.TRAINER, F.VENDOR, F.IBOP, F.RBOP)
	self:AddRecipeAcquire(32667, A.VENDOR, 19663, A.TRAINER, 28693, A.TRAINER, 33583, A.TRAINER, 26990, A.TRAINER, 26980, A.TRAINER, 26954, A.TRAINER, 26906)

	-- Enchant Chest - Major Spirit -- 33990
	AddRecipe(33990, 320, nil, Q.COMMON, V.TBC, 320, 330, 345, 360)
	self:AddRecipeFlags(33990, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE, F.HEALER, F.CASTER)
	self:AddRecipeAcquire(33990, A.TRAINER, 18753, A.TRAINER, 18773, A.TRAINER, 19252, A.TRAINER, 19540, A.TRAINER, 33610, A.TRAINER, 33676)

	-- Enchant Chest - Restore Mana Prime -- 33991
	AddRecipe(33991, 300, nil, Q.COMMON, V.TBC, 300, 310, 325, 340)
	self:AddRecipeFlags(33991, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE, F.HEALER, F.CASTER)
	self:AddRecipeAcquire(33991, A.TRAINER, 18753, A.TRAINER, 18773, A.TRAINER, 19252, A.TRAINER, 19540, A.TRAINER, 33610, A.TRAINER, 33676)

	-- Enchant Chest - Major Resilience -- 33992
	AddRecipe(33992, 345, nil, Q.UNCOMMON, V.TBC, 345, 355, 367, 380)
	self:AddRecipeFlags(33992, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE)
	self:AddRecipeAcquire(33992, A.WORLD_DROP, 2)

	-- Enchant Gloves - Blasting -- 33993
	AddRecipe(33993, 305, nil, Q.COMMON, V.TBC, 305, 315, 330, 345)
	self:AddRecipeFlags(33993, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE)
	self:AddRecipeAcquire(33993, A.TRAINER, 18753, A.TRAINER, 18773, A.TRAINER, 19252, A.TRAINER, 19540, A.TRAINER, 33610, A.TRAINER, 33676)

	-- Enchant Gloves - Precise Strikes -- 33994
	AddRecipe(33994, 360, nil, Q.COMMON, V.TBC, 360, 370, 377, 385)
	self:AddRecipeFlags(33994, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE, F.CENARION_EXPEDITION)
	self:AddRecipeAcquire(33994, A.REPUTATION, FAC.CENARION_EXPEDITION, REP.REVERED, 17904)

	-- Enchant Gloves - Major Strength -- 33995
	AddRecipe(33995, 340, nil, Q.COMMON, V.TBC, 340, 350, 365, 380)
	self:AddRecipeFlags(33995, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE, F.DPS)
	self:AddRecipeAcquire(33995, A.TRAINER, 18753, A.TRAINER, 18773, A.TRAINER, 19252, A.TRAINER, 19540, A.TRAINER, 33610, A.TRAINER, 33676)

	-- Enchant Gloves - Assault -- 33996
	AddRecipe(33996, 310, nil, Q.COMMON, V.TBC, 310, 320, 335, 350)
	self:AddRecipeFlags(33996, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE, F.DPS)
	self:AddRecipeAcquire(33996, A.TRAINER, 18753, A.TRAINER, 18773, A.TRAINER, 19252, A.TRAINER, 19540, A.TRAINER, 33610, A.TRAINER, 33676)

	-- Enchant Gloves - Major Spellpower -- 33997
	AddRecipe(33997, 360, nil, Q.COMMON, V.TBC, 360, 370, 377, 385)
	self:AddRecipeFlags(33997, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.KOT)
	self:AddRecipeAcquire(33997, A.REPUTATION, FAC.KEEPERS_OF_TIME, REP.HONORED, 21643)

	-- Enchant Gloves - Major Healing -- 33999
	AddRecipe(33999, 350, nil, Q.COMMON, V.TBC, 350, 370, 375, 380)
	self:AddRecipeFlags(33999, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.SHATAR)
	self:AddRecipeAcquire(33999, A.REPUTATION, FAC.SHATAR, REP.HONORED, 21432)

	-- Enchant Bracer - Major Intellect -- 34001
	AddRecipe(34001, 305, nil, Q.COMMON, V.TBC, 305, 315, 330, 345)
	self:AddRecipeFlags(34001, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE)
	self:AddRecipeAcquire(34001, A.TRAINER, 18753, A.TRAINER, 18773, A.TRAINER, 19252, A.TRAINER, 19540, A.TRAINER, 33610, A.TRAINER, 33676)

	-- Enchant Bracer - Assault -- 34002
	AddRecipe(34002, 300, nil, Q.COMMON, V.TBC, 300, 310, 325, 340)
	self:AddRecipeFlags(34002, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE, F.DPS)
	self:AddRecipeAcquire(34002, A.TRAINER, 18753, A.TRAINER, 18773, A.TRAINER, 19252, A.TRAINER, 19540, A.TRAINER, 33610, A.TRAINER, 33676)

	-- Enchant Cloak - Spell Penetration -- 34003
	AddRecipe(34003, 325, nil, Q.COMMON, V.TBC, 325, 335, 350, 365)
	self:AddRecipeFlags(34003, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE, F.CASTER, F.CLOAK, F.CONSORTIUM)
	self:AddRecipeAcquire(34003, A.REPUTATION, FAC.CONSORTIUM, REP.FRIENDLY, 20242, A.REPUTATION, FAC.CONSORTIUM, REP.FRIENDLY, 23007)

	-- Enchant Cloak - Greater Agility -- 34004
	AddRecipe(34004, 310, nil, Q.COMMON, V.TBC, 310, 320, 335, 350)
	self:AddRecipeFlags(34004, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE, F.DPS, F.CLOAK)
	self:AddRecipeAcquire(34004, A.TRAINER, 18753, A.TRAINER, 18773, A.TRAINER, 19252, A.TRAINER, 19540, A.TRAINER, 33610, A.TRAINER, 33676)

	-- Enchant Cloak - Greater Arcane Resistance -- 34005
	AddRecipe(34005, 350, nil, Q.RARE, V.TBC, 350, 370, 375, 380)
	self:AddRecipeFlags(34005, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOE, F.CLOAK)
	self:AddRecipeAcquire(34005, A.MOB, 19796)

	-- Enchant Cloak - Greater Shadow Resistance -- 34006
	AddRecipe(34006, 350, nil, Q.RARE, V.TBC, 350, 370, 375, 380)
	self:AddRecipeFlags(34006, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOE, F.CLOAK)
	self:AddRecipeAcquire(34006, A.MOB, 18870)

	-- Enchant Boots - Cat's Swiftness -- 34007
	AddRecipe(34007, 360, nil, Q.RARE, V.TBC, 360, 370, 377, 385)
	self:AddRecipeFlags(34007, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOE, F.DPS)
	self:AddRecipeAcquire(34007, A.MOB, 24664)

	-- Enchant Boots - Boar's Speed -- 34008
	AddRecipe(34008, 360, nil, Q.RARE, V.TBC, 360, 370, 377, 385)
	self:AddRecipeFlags(34008, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOE)
	self:AddRecipeAcquire(34008, A.MOB, 24664)

	-- Enchant Shield - Major Stamina -- 34009
	AddRecipe(34009, 325, nil, Q.COMMON, V.TBC, 325, 335, 350, 365)
	self:AddRecipeFlags(34009, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE, F.SHIELD)
	self:AddRecipeAcquire(34009, A.VENDOR, 19663)

	-- Enchant Weapon - Major Healing -- 34010
	AddRecipe(34010, 350, nil, Q.COMMON, V.TBC, 350, 370, 375, 380)
	self:AddRecipeFlags(34010, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.ONE_HAND, F.TWO_HAND, F.SHATAR)
	self:AddRecipeAcquire(34010, A.REPUTATION, FAC.SHATAR, REP.REVERED, 21432)

	-- Nexus Transformation -- 42613
	AddRecipe(42613, 300, 22448, Q.COMMON, V.TBC, 300, 300, 300, 305)
	self:AddRecipeFlags(42613, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:AddRecipeAcquire(42613, A.TRAINER, 18753, A.TRAINER, 18773, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 33676, A.TRAINER, 19540)

	-- Small Prismatic Shard -- 42615
	AddRecipe(42615, 335, 22448, Q.COMMON, V.TBC, 335, 335, 335, 335)
	self:AddRecipeFlags(42615, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:AddRecipeAcquire(42615, A.TRAINER, 18753, A.TRAINER, 18773, A.TRAINER, 19252, A.TRAINER, 19540, A.TRAINER, 33610, A.TRAINER, 33676)

	-- Enchant Weapon - Greater Agility -- 42620
	AddRecipe(42620, 350, nil, Q.COMMON, V.TBC, 350, 360, 367, 375)
	self:AddRecipeFlags(42620, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE, F.DPS, F.ONE_HAND, F.TWO_HAND, F.VIOLETEYE)
	self:AddRecipeAcquire(42620, A.REPUTATION, FAC.VIOLETEYE, REP.EXALTED, 18255)

	-- Enchant Weapon - Executioner -- 42974
	AddRecipe(42974, 375, nil, Q.RARE, V.TBC, 375, 380, 385, 390)
	self:AddRecipeFlags(42974, F.ALLIANCE, F.HORDE, F.RAID, F.IBOE, F.RBOE, F.DPS, F.ONE_HAND, F.TWO_HAND)
	self:AddRecipeAcquire(42974, A.CUSTOM, 29)

	-- Enchant Shield - Resilience -- 44383
	AddRecipe(44383, 330, nil, Q.COMMON, V.TBC, 330, 340, 355, 370)
	self:AddRecipeFlags(44383, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.SHIELD)
	self:AddRecipeAcquire(44383, A.TRAINER, 18753, A.TRAINER, 18773, A.TRAINER, 19252, A.TRAINER, 19540, A.TRAINER, 33610, A.TRAINER, 33676)

	-- Enchant Cloak - Superior Frost Resistance -- 44483
	AddRecipe(44483, 400, nil, Q.COMMON, V.WOTLK, 400, 415, 425, 435)
	self:AddRecipeFlags(44483, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOE, F.CLOAK)
	self:AddRecipeAcquire(44483, A.MOB, 32289)

	-- Enchant Gloves - Expertise -- 44484
	AddRecipe(44484, 405, nil, Q.COMMON, V.WOTLK, 405, 415, 425, 435)
	self:AddRecipeFlags(44484, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.TANK)
	self:AddRecipeAcquire(44484, A.TRAINER, 26906, A.TRAINER, 26954, A.TRAINER, 26980, A.TRAINER, 26990, A.TRAINER, 28693, A.TRAINER, 33583)

	-- Enchant Gloves - Precision -- 44488
	AddRecipe(44488, 410, nil, Q.COMMON, V.WOTLK, 410, 420, 430, 440)
	self:AddRecipeFlags(44488, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:AddRecipeAcquire(44488, A.TRAINER, 26906, A.TRAINER, 26954, A.TRAINER, 26980, A.TRAINER, 26990, A.TRAINER, 28693, A.TRAINER, 33583)

	-- Enchant Shield - Defense -- 44489
	AddRecipe(44489, 420, nil, Q.COMMON, V.WOTLK, 420, 430, 440, 450)
	self:AddRecipeFlags(44489, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.TANK, F.SHIELD)
	self:AddRecipeAcquire(44489, A.TRAINER, 26906, A.TRAINER, 26954, A.TRAINER, 26980, A.TRAINER, 26990, A.TRAINER, 28693, A.TRAINER, 33583)

	-- Enchant Chest - Mighty Health -- 44492
	AddRecipe(44492, 395, nil, Q.COMMON, V.WOTLK, 395, 405, 415, 425)
	self:AddRecipeFlags(44492, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:AddRecipeAcquire(44492, A.TRAINER, 26906, A.TRAINER, 26954, A.TRAINER, 26980, A.TRAINER, 26990, A.TRAINER, 28693, A.TRAINER, 33583)

	-- Enchant Cloak - Superior Nature Resistance -- 44494
	AddRecipe(44494, 400, nil, Q.COMMON, V.WOTLK, 400, 415, 425, 435)
	self:AddRecipeFlags(44494, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOE, F.CLOAK)
	self:AddRecipeAcquire(44494, A.MOB, 32290)

	-- Enchant Cloak - Superior Agility -- 44500
	AddRecipe(44500, 395, nil, Q.COMMON, V.WOTLK, 395, 405, 415, 425)
	self:AddRecipeFlags(44500, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.CLOAK)
	self:AddRecipeAcquire(44500, A.TRAINER, 26906, A.TRAINER, 26954, A.TRAINER, 26980, A.TRAINER, 26990, A.TRAINER, 28693, A.TRAINER, 33583)

	-- Enchant Gloves - Gatherer -- 44506
	AddRecipe(44506, 375, nil, Q.COMMON, V.WOTLK, 375, 375, 380, 390)
	self:AddRecipeFlags(44506, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:AddRecipeAcquire(44506, A.TRAINER, 26906, A.TRAINER, 26954, A.TRAINER, 26980, A.TRAINER, 26990, A.TRAINER, 28693, A.TRAINER, 33583)

	-- Enchant Boots - Greater Spirit -- 44508
	AddRecipe(44508, 410, nil, Q.COMMON, V.WOTLK, 410, 420, 430, 440)
	self:AddRecipeFlags(44508, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER)
	self:AddRecipeAcquire(44508, A.TRAINER, 26906, A.TRAINER, 26954, A.TRAINER, 26980, A.TRAINER, 26990, A.TRAINER, 28693, A.TRAINER, 33583)

	-- Enchant Chest - Greater Mana Restoration -- 44509
	AddRecipe(44509, 420, nil, Q.COMMON, V.WOTLK, 420, 430, 440, 450)
	self:AddRecipeFlags(44509, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER)
	self:AddRecipeAcquire(44509, A.TRAINER, 26906, A.TRAINER, 26954, A.TRAINER, 26980, A.TRAINER, 26990, A.TRAINER, 28693, A.TRAINER, 33583)

	-- Enchant Weapon - Exceptional Spirit -- 44510
	AddRecipe(44510, 410, nil, Q.COMMON, V.WOTLK, 410, 420, 430, 440)
	self:AddRecipeFlags(44510, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.ONE_HAND, F.TWO_HAND)
	self:AddRecipeAcquire(44510, A.TRAINER, 26906, A.TRAINER, 26954, A.TRAINER, 26980, A.TRAINER, 26990, A.TRAINER, 28693, A.TRAINER, 33583)

	-- Enchant Gloves - Greater Assault -- 44513
	AddRecipe(44513, 395, nil, Q.COMMON, V.WOTLK, 395, 405, 415, 425)
	self:AddRecipeFlags(44513, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS)
	self:AddRecipeAcquire(44513, A.TRAINER, 26906, A.TRAINER, 26954, A.TRAINER, 26980, A.TRAINER, 26990, A.TRAINER, 28693, A.TRAINER, 33583)

	-- Enchant Weapon - Icebreaker -- 44524
	AddRecipe(44524, 425, nil, Q.RARE, V.WOTLK, 425, 435, 445, 455)
	self:AddRecipeFlags(44524, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE, F.ONE_HAND, F.TWO_HAND)
	self:AddRecipeAcquire(44524, A.VENDOR, 32514)

	-- Enchant Boots - Greater Fortitude -- 44528
	AddRecipe(44528, 385, nil, Q.COMMON, V.WOTLK, 385, 385, 390, 400)
	self:AddRecipeFlags(44528, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:AddRecipeAcquire(44528, A.TRAINER, 26906, A.TRAINER, 26954, A.TRAINER, 26980, A.TRAINER, 26990, A.TRAINER, 28693, A.TRAINER, 33583)

	-- Enchant Gloves - Major Agility -- 44529
	AddRecipe(44529, 415, nil, Q.COMMON, V.WOTLK, 415, 425, 435, 445)
	self:AddRecipeFlags(44529, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS)
	self:AddRecipeAcquire(44529, A.TRAINER, 26906, A.TRAINER, 26954, A.TRAINER, 26980, A.TRAINER, 26990, A.TRAINER, 28693, A.TRAINER, 33583)

	-- Enchant Bracers - Exceptional Intellect -- 44555
	AddRecipe(44555, 375, nil, Q.COMMON, V.WOTLK, 375, 385, 392, 400)
	self:AddRecipeFlags(44555, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:AddRecipeAcquire(44555, A.TRAINER, 26906, A.TRAINER, 26954, A.TRAINER, 26980, A.TRAINER, 26990, A.TRAINER, 28693, A.TRAINER, 33583)

	-- Enchant Cloak - Superior Fire Resistance -- 44556
	AddRecipe(44556, 400, nil, Q.COMMON, V.WOTLK, 400, 415, 425, 435)
	self:AddRecipeFlags(44556, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOE, F.CLOAK)
	self:AddRecipeAcquire(44556, A.MOB, 30921)

	-- Enchant Bracers - Greater Assault -- 44575
	AddRecipe(44575, 430, nil, Q.COMMON, V.WOTLK, 430, 440, 450, 460)
	self:AddRecipeFlags(44575, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE, F.DPS)
	self:AddRecipeAcquire(44575, A.VENDOR, 32514)

	-- Enchant Weapon - Lifeward -- 44576
	AddRecipe(44576, 425, nil, Q.RARE, V.WOTLK, 425, 435, 445, 455)
	self:AddRecipeFlags(44576, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.ONE_HAND, F.TWO_HAND)
	self:AddRecipeAcquire(44576, A.VENDOR, 32514)

	-- Enchant Cloak - Spell Piercing -- 44582
	AddRecipe(44582, 395, nil, Q.COMMON, V.WOTLK, 395, 395, 402, 410)
	self:AddRecipeFlags(44582, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.CASTER, F.CLOAK)
	self:AddRecipeAcquire(44582, A.TRAINER, 26906, A.TRAINER, 26954, A.TRAINER, 26980, A.TRAINER, 26990, A.TRAINER, 28693, A.TRAINER, 33583)

	-- Enchant Boots - Greater Vitality -- 44584
	AddRecipe(44584, 405, nil, Q.COMMON, V.WOTLK, 405, 415, 425, 435)
	self:AddRecipeFlags(44584, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:AddRecipeAcquire(44584, A.TRAINER, 26906, A.TRAINER, 26954, A.TRAINER, 26980, A.TRAINER, 26990, A.TRAINER, 28693, A.TRAINER, 33583)

	-- Enchant Chest - Exceptional Resilience -- 44588
	AddRecipe(44588, 410, nil, Q.UNCOMMON, V.WOTLK, 410, 435, 445, 455)
	self:AddRecipeFlags(44588, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP)
	self:AddRecipeAcquire(44588, A.VENDOR, 32514)

	-- Enchant Boots - Superior Agility -- 44589
	AddRecipe(44589, 415, nil, Q.COMMON, V.WOTLK, 415, 425, 435, 445)
	self:AddRecipeFlags(44589, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS)
	self:AddRecipeAcquire(44589, A.TRAINER, 26906, A.TRAINER, 26954, A.TRAINER, 26980, A.TRAINER, 26990, A.TRAINER, 28693, A.TRAINER, 33583)

	-- Enchant Cloak - Superior Shadow Resistance -- 44590
	AddRecipe(44590, 400, nil, Q.COMMON, V.WOTLK, 400, 415, 425, 435)
	self:AddRecipeFlags(44590, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOE, F.CLOAK)
	self:AddRecipeAcquire(44590, A.MOB, 32349)

	-- Enchant Cloak - Titanweave -- 44591
	AddRecipe(44591, 435, nil, Q.COMMON, V.WOTLK, 435, 445, 455, 465)
	self:AddRecipeFlags(44591, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE, F.TANK, F.CLOAK)
	self:AddRecipeAcquire(44591, A.VENDOR, 32514)

	-- Enchant Gloves - Exceptional Spellpower -- 44592
	AddRecipe(44592, 360, nil, Q.COMMON, V.WOTLK, 360, 370, 380, 390)
	self:AddRecipeFlags(44592, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER)
	self:AddRecipeAcquire(44592, A.TRAINER, 26906, A.TRAINER, 26954, A.TRAINER, 26980, A.TRAINER, 26990, A.TRAINER, 28693, A.TRAINER, 33583)

	-- Enchant Bracers - Major Spirit -- 44593
	AddRecipe(44593, 420, nil, Q.COMMON, V.WOTLK, 420, 430, 440, 450)
	self:AddRecipeFlags(44593, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER)
	self:AddRecipeAcquire(44593, A.TRAINER, 26906, A.TRAINER, 26954, A.TRAINER, 26980, A.TRAINER, 26990, A.TRAINER, 28693, A.TRAINER, 33583)

	-- Enchant 2H Weapon - Scourgebane -- 44595
	AddRecipe(44595, 430, 44473, Q.RARE, V.WOTLK, 430, 440, 450, 460)
	self:AddRecipeFlags(44595, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.DPS, F.ONE_HAND, F.TWO_HAND)
	self:AddRecipeAcquire(44595, A.VENDOR, 32514)

	-- Enchant Cloak - Superior Arcane Resistance -- 44596
	AddRecipe(44596, 400, nil, Q.COMMON, V.WOTLK, 400, 415, 425, 435)
	self:AddRecipeFlags(44596, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOE, F.CLOAK)
	self:AddRecipeAcquire(44596, A.MOB, 31702, A.MOB, 32297)

	-- Enchant Bracers - Expertise -- 44598
	AddRecipe(44598, 415, nil, Q.COMMON, V.WOTLK, 415, 425, 435, 445)
	self:AddRecipeFlags(44598, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.TANK)
	self:AddRecipeAcquire(44598, A.TRAINER, 26906, A.TRAINER, 26954, A.TRAINER, 26980, A.TRAINER, 26990, A.TRAINER, 28693, A.TRAINER, 33583)

	-- Enchant Bracers - Greater Stats -- 44616
	AddRecipe(44616, 400, nil, Q.COMMON, V.WOTLK, 400, 410, 420, 430)
	self:AddRecipeFlags(44616, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:AddRecipeAcquire(44616, A.TRAINER, 26906, A.TRAINER, 26954, A.TRAINER, 26980, A.TRAINER, 26990, A.TRAINER, 28693, A.TRAINER, 33583)

	-- Enchant Weapon - Giant Slayer -- 44621
	AddRecipe(44621, 430, nil, Q.RARE, V.WOTLK, 430, 440, 450, 460)
	self:AddRecipeFlags(44621, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE, F.ONE_HAND, F.TWO_HAND)
	self:AddRecipeAcquire(44621, A.VENDOR, 32514)

	-- Enchant Chest - Super Stats -- 44623
	AddRecipe(44623, 370, nil, Q.COMMON, V.WOTLK, 370, 380, 390, 400)
	self:AddRecipeFlags(44623, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:AddRecipeAcquire(44623, A.TRAINER, 26906, A.TRAINER, 26954, A.TRAINER, 26980, A.TRAINER, 26990, A.TRAINER, 28693, A.TRAINER, 33583)

	-- Enchant Gloves - Armsman -- 44625
	AddRecipe(44625, 435, nil, Q.UNCOMMON, V.WOTLK, 435, 445, 455, 465)
	self:AddRecipeFlags(44625, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.TANK)
	self:AddRecipeAcquire(44625, A.VENDOR, 32514)

	-- Enchant Weapon - Exceptional Spellpower -- 44629
	AddRecipe(44629, 395, nil, Q.COMMON, V.WOTLK, 395, 405, 415, 425)
	self:AddRecipeFlags(44629, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.ONE_HAND, F.TWO_HAND)
	self:AddRecipeAcquire(44629, A.TRAINER, 26906, A.TRAINER, 26954, A.TRAINER, 26980, A.TRAINER, 26990, A.TRAINER, 28693, A.TRAINER, 33583)

	-- Enchant 2H Weapon - Greater Savagery -- 44630
	AddRecipe(44630, 390, nil, Q.COMMON, V.WOTLK, 390, 400, 410, 420)
	self:AddRecipeFlags(44630, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.TWO_HAND)
	self:AddRecipeAcquire(44630, A.TRAINER, 26906, A.TRAINER, 26954, A.TRAINER, 26980, A.TRAINER, 26990, A.TRAINER, 28693, A.TRAINER, 33583)

	-- Enchant Cloak - Shadow Armor -- 44631
	AddRecipe(44631, 440, nil, Q.COMMON, V.WOTLK, 440, 450, 460, 470)
	self:AddRecipeFlags(44631, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE, F.DPS, F.CLOAK)
	self:AddRecipeAcquire(44631, A.VENDOR, 32514)

	-- Enchant Weapon - Exceptional Agility -- 44633
	AddRecipe(44633, 410, nil, Q.COMMON, V.WOTLK, 410, 420, 430, 440)
	self:AddRecipeFlags(44633, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.ONE_HAND, F.TWO_HAND)
	self:AddRecipeAcquire(44633, A.TRAINER, 26906, A.TRAINER, 26954, A.TRAINER, 26980, A.TRAINER, 26990, A.TRAINER, 28693, A.TRAINER, 33583)

	-- Enchant Bracers - Greater Spellpower -- 44635
	AddRecipe(44635, 395, nil, Q.COMMON, V.WOTLK, 395, 405, 415, 425)
	self:AddRecipeFlags(44635, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER)
	self:AddRecipeAcquire(44635, A.TRAINER, 26906, A.TRAINER, 26954, A.TRAINER, 26980, A.TRAINER, 26990, A.TRAINER, 28693, A.TRAINER, 33583)

	-- Enchant Ring - Greater Spellpower -- 44636
	AddRecipe(44636, 400, nil, Q.COMMON, V.WOTLK, 400, 400, 407, 415)
	self:AddRecipeFlags(44636, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.RING)
	self:AddRecipeAcquire(44636, A.TRAINER, 26906, A.TRAINER, 26954, A.TRAINER, 26980, A.TRAINER, 26990, A.TRAINER, 28693, A.TRAINER, 33583)

	-- Enchant Ring - Assault -- 44645
	AddRecipe(44645, 400, nil, Q.COMMON, V.WOTLK, 400, 400, 407, 415)
	self:AddRecipeFlags(44645, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.RING)
	self:AddRecipeAcquire(44645, A.TRAINER, 26906, A.TRAINER, 26954, A.TRAINER, 26980, A.TRAINER, 26990, A.TRAINER, 28693, A.TRAINER, 33583)

	-- Void Shatter -- 45765
	AddRecipe(45765, 375, 22449, Q.COMMON, V.TBC, 375, 375, 375, 375)
	self:AddRecipeFlags(45765, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.SHATTEREDSUN)
	self:AddRecipeAcquire(45765, A.REPUTATION, FAC.SHATTEREDSUN, REP.HONORED, 25032)

	-- Enchant Weapon - Deathfrost -- 46578
	AddRecipe(46578, 350, nil, Q.RARE, V.TBC, 350, 350, 357, 365)
	self:AddRecipeFlags(46578, F.ALLIANCE, F.HORDE, F.SEASONAL, F.IBOE, F.RBOE, F.ONE_HAND, F.TWO_HAND)
	self:AddRecipeAcquire(46578, A.SEASONAL, 4)

	-- Enchant Chest - Defense -- 46594
	AddRecipe(46594, 360, nil, Q.COMMON, V.WOTLK, 360, 370, 385, 400)
	self:AddRecipeFlags(46594, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE, F.TANK, F.SHATTEREDSUN)
	self:AddRecipeAcquire(46594, A.REPUTATION, FAC.SHATTEREDSUN, REP.HONORED, 25032)

	-- Enchant Cloak - Steelweave -- 47051
	AddRecipe(47051, 375, nil, Q.RARE, V.TBC, 375, 380, 385, 390)
	self:AddRecipeFlags(47051, F.ALLIANCE, F.HORDE, F.INSTANCE, F.IBOE, F.RBOE, F.TANK, F.CLOAK)
	self:AddRecipeAcquire(47051, A.MOB, 24560)

	-- Enchant Cloak - Mighty Armor -- 47672
	AddRecipe(47672, 430, nil, Q.UNCOMMON, V.WOTLK, 430, 440, 450, 460)
	self:AddRecipeFlags(47672, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.CLOAK)
	self:AddRecipeAcquire(47672, A.VENDOR, 32514)

	-- Enchant Chest - Greater Defense -- 47766
	AddRecipe(47766, 400, nil, Q.COMMON, V.WOTLK, 400, 410, 420, 430)
	self:AddRecipeFlags(47766, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.TANK)
	self:AddRecipeAcquire(47766, A.TRAINER, 26906, A.TRAINER, 26954, A.TRAINER, 26980, A.TRAINER, 26990, A.TRAINER, 28693, A.TRAINER, 33583)

	-- Enchant Cloak - Greater Speed -- 47898
	AddRecipe(47898, 430, nil, Q.UNCOMMON, V.WOTLK, 430, 440, 450, 460)
	self:AddRecipeFlags(47898, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.CLOAK)
	self:AddRecipeAcquire(47898, A.VENDOR, 32514)

	-- Enchant Cloak - Wisdom -- 47899
	AddRecipe(47899, 440, nil, Q.UNCOMMON, V.WOTLK, 440, 450, 460, 470)
	self:AddRecipeFlags(47899, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOAK)
	self:AddRecipeAcquire(47899, A.VENDOR, 32514)

	-- Enchant Chest - Super Health -- 47900
	AddRecipe(47900, 425, nil, Q.COMMON, V.WOTLK, 425, 435, 445, 455)
	self:AddRecipeFlags(47900, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:AddRecipeAcquire(47900, A.TRAINER, 26906, A.TRAINER, 26954, A.TRAINER, 26980, A.TRAINER, 26990, A.TRAINER, 28693, A.TRAINER, 33583)

	-- Enchant Boots - Tuskarr's Vitality -- 47901
	AddRecipe(47901, 440, nil, Q.UNCOMMON, V.WOTLK, 440, 450, 460, 470)
	self:AddRecipeFlags(47901, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP)
	self:AddRecipeAcquire(47901, A.VENDOR, 32514)

	-- Enchant Weapon - Accuracy -- 59619
	AddRecipe(59619, 440, nil, Q.RARE, V.WOTLK, 440, 450, 460, 470)
	self:AddRecipeFlags(59619, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE, F.ONE_HAND, F.TWO_HAND)
	self:AddRecipeAcquire(59619, A.VENDOR, 32514)

	-- Enchant Weapon - Berserking -- 59621
	AddRecipe(59621, 440, nil, Q.RARE, V.WOTLK, 440, 450, 460, 470)
	self:AddRecipeFlags(59621, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE, F.DPS, F.ONE_HAND, F.TWO_HAND)
	self:AddRecipeAcquire(59621, A.VENDOR, 32514)

	-- Enchant Weapon - Black Magic -- 59625
	AddRecipe(59625, 440, nil, Q.RARE, V.WOTLK, 440, 450, 460, 470)
	self:AddRecipeFlags(59625, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.ONE_HAND, F.TWO_HAND)
	self:AddRecipeAcquire(59625, A.VENDOR, 32514)

	-- Enchant Ring - Stamina -- 59636
	AddRecipe(59636, 400, nil, Q.COMMON, V.WOTLK, 400, 400, 407, 415)
	self:AddRecipeFlags(59636, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.RING)
	self:AddRecipeAcquire(59636, A.TRAINER, 26906, A.TRAINER, 26954, A.TRAINER, 26980, A.TRAINER, 26990, A.TRAINER, 28693, A.TRAINER, 33583)

	-- Enchant Boots - Assault -- 60606
	AddRecipe(60606, 375, nil, Q.COMMON, V.WOTLK, 375, 385, 395, 405)
	self:AddRecipeFlags(60606, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS)
	self:AddRecipeAcquire(60606, A.TRAINER, 26906, A.TRAINER, 26954, A.TRAINER, 26980, A.TRAINER, 26990, A.TRAINER, 28693, A.TRAINER, 33583)

	-- Enchant Cloak - Speed -- 60609
	AddRecipe(60609, 350, nil, Q.COMMON, V.WOTLK, 350, 360, 370, 380)
	self:AddRecipeFlags(60609, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.CLOAK)
	self:AddRecipeAcquire(60609, A.TRAINER, 26906, A.TRAINER, 26954, A.TRAINER, 26980, A.TRAINER, 26990, A.TRAINER, 28693, A.TRAINER, 33583)

	-- Enchant Bracers - Striking -- 60616
	AddRecipe(60616, 360, nil, Q.COMMON, V.WOTLK, 360, 370, 380, 390)
	self:AddRecipeFlags(60616, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS)
	self:AddRecipeAcquire(60616, A.TRAINER, 26906, A.TRAINER, 26954, A.TRAINER, 26980, A.TRAINER, 26990, A.TRAINER, 28693, A.TRAINER, 33583)

	-- Runed Titanium Rod -- 60619
	AddRecipe(60619, 425, 44452, Q.RARE, V.WOTLK, 425, 435, 445, 455)
	self:AddRecipeFlags(60619, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOP, F.RBOP)
	self:AddRecipeAcquire(60619, A.TRAINER, 26906, A.TRAINER, 26954, A.TRAINER, 26980, A.TRAINER, 26990, A.TRAINER, 28693, A.TRAINER, 33583)

	-- Enchant Weapon - Greater Potency -- 60621
	AddRecipe(60621, 380, nil, Q.COMMON, V.WOTLK, 380, 390, 400, 410)
	self:AddRecipeFlags(60621, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.ONE_HAND, F.TWO_HAND)
	self:AddRecipeAcquire(60621, A.TRAINER, 26906, A.TRAINER, 26954, A.TRAINER, 26980, A.TRAINER, 26990, A.TRAINER, 28693, A.TRAINER, 33583)

	-- Enchant Boots - Icewalker -- 60623
	AddRecipe(60623, 385, nil, Q.COMMON, V.WOTLK, 385, 395, 405, 415)
	self:AddRecipeFlags(60623, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:AddRecipeAcquire(60623, A.TRAINER, 26906, A.TRAINER, 26954, A.TRAINER, 26980, A.TRAINER, 26990, A.TRAINER, 28693, A.TRAINER, 33583)

	-- Enchant Shield - Greater Intellect -- 60653
	AddRecipe(60653, 395, nil, Q.COMMON, V.WOTLK, 395, 405, 415, 425)
	self:AddRecipeFlags(60653, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.SHIELD)
	self:AddRecipeAcquire(60653, A.TRAINER, 26906, A.TRAINER, 26954, A.TRAINER, 26980, A.TRAINER, 26990, A.TRAINER, 28693, A.TRAINER, 33583)

	-- Enchant Cloak - Major Agility -- 60663
	AddRecipe(60663, 420, nil, Q.COMMON, V.WOTLK, 420, 430, 440, 450)
	self:AddRecipeFlags(60663, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.CLOAK)
	self:AddRecipeAcquire(60663, A.TRAINER, 26906, A.TRAINER, 26954, A.TRAINER, 26980, A.TRAINER, 26990, A.TRAINER, 28693, A.TRAINER, 33583)

	-- Enchant Gloves - Crusher -- 60668
	AddRecipe(60668, 425, nil, Q.COMMON, V.WOTLK, 425, 435, 445, 455)
	self:AddRecipeFlags(60668, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS)
	self:AddRecipeAcquire(60668, A.TRAINER, 26906, A.TRAINER, 26954, A.TRAINER, 26980, A.TRAINER, 26990, A.TRAINER, 28693, A.TRAINER, 33583)

	-- Enchant 2H Weapon - Massacre -- 60691
	AddRecipe(60691, 430, nil, Q.RARE, V.WOTLK, 430, 440, 450, 460)
	self:AddRecipeFlags(60691, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.DPS, F.TWO_HAND)
	self:AddRecipeAcquire(60691, A.VENDOR, 32514)

	-- Enchant Chest - Powerful Stats -- 60692
	AddRecipe(60692, 440, nil, Q.UNCOMMON, V.WOTLK, 440, 450, 460, 470)
	self:AddRecipeFlags(60692, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP)
	self:AddRecipeAcquire(60692, A.VENDOR, 32514)

	-- Enchant Weapon - Superior Potency -- 60707
	AddRecipe(60707, 435, nil, Q.RARE, V.WOTLK, 435, 445, 455, 465)
	self:AddRecipeFlags(60707, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.DPS, F.ONE_HAND, F.TWO_HAND)
	self:AddRecipeAcquire(60707, A.VENDOR, 32514)

	-- Enchant Weapon - Mighty Spellpower -- 60714
	AddRecipe(60714, 435, nil, Q.RARE, V.WOTLK, 435, 445, 455, 465)
	self:AddRecipeFlags(60714, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.ONE_HAND, F.TWO_HAND)
	self:AddRecipeAcquire(60714, A.VENDOR, 32514)

	-- Enchant Boots - Greater Assault -- 60763
	AddRecipe(60763, 440, nil, Q.UNCOMMON, V.WOTLK, 440, 450, 460, 470)
	self:AddRecipeFlags(60763, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.DPS)
	self:AddRecipeAcquire(60763, A.VENDOR, 32514)

	-- Enchant Bracers - Superior Spellpower -- 60767
	AddRecipe(60767, 440, 44498, Q.UNCOMMON, V.WOTLK, 440, 450, 460, 470)
	self:AddRecipeFlags(60767, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.HEALER, F.CASTER)
	self:AddRecipeAcquire(60767, A.VENDOR, 32514)

	-- Enchant Bracers - Major Stamina -- 62256
	AddRecipe(62256, 450, 44944, Q.RARE, V.WOTLK, 450, 460, 470, 480)
	self:AddRecipeFlags(62256, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP)
	self:AddRecipeAcquire(62256, A.VENDOR, 32514)

	-- Enchant Staff - Greater Spellpower -- 62948
	AddRecipe(62948, 450, nil, Q.RARE, V.WOTLK, 450, 455, 460, 465)
	self:AddRecipeFlags(62948, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.STAFF)
	self:AddRecipeAcquire(62948, A.VENDOR, 32514)

	-- Enchant Staff - Spellpower -- 62959
	AddRecipe(62959, 385, nil, Q.COMMON, V.WOTLK, 385, 395, 405, 415)
	self:AddRecipeFlags(62959, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.STAFF)
	self:AddRecipeAcquire(62959, A.TRAINER, 26906, A.TRAINER, 26954, A.TRAINER, 26980, A.TRAINER, 26990, A.TRAINER, 28693, A.TRAINER, 33583)

	-- Enchant Boots - Lesser Accuracy -- 63746
	AddRecipe(63746, 225, nil, Q.COMMON, V.WOTLK, 225, 245, 265, 285)
	self:AddRecipeFlags(63746, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS)
	self:AddRecipeAcquire(63746, A.TRAINER, 1317, A.TRAINER, 3011, A.TRAINER, 3345, A.TRAINER, 3606, A.TRAINER, 4213, A.TRAINER, 4616, A.TRAINER, 5157, A.TRAINER, 5695, A.TRAINER, 11072, A.TRAINER, 11073, A.TRAINER, 11074, A.TRAINER, 16160, A.TRAINER, 16633, A.TRAINER, 16725, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 7949, A.TRAINER, 19540, A.TRAINER, 18753)

	-- Enchant Weapon - Blade Ward -- 64441
	AddRecipe(64441, 450, nil, Q.EPIC, V.WOTLK, 450, 455, 460, 465)
	self:AddRecipeFlags(64441, F.ALLIANCE, F.HORDE, F.RAID, F.MOB_DROP, F.IBOE, F.RBOP, F.TANK, F.ONE_HAND, F.TWO_HAND)
	self:AddRecipeAcquire(64441, A.CUSTOM, 39)

	-- Enchant Weapon - Blood Draining -- 64579
	AddRecipe(64579, 450, nil, Q.EPIC, V.WOTLK, 450, 455, 460, 465)
	self:AddRecipeFlags(64579, F.ALLIANCE, F.HORDE, F.RAID, F.MOB_DROP, F.IBOE, F.RBOP, F.ONE_HAND, F.TWO_HAND)
	self:AddRecipeAcquire(64579, A.CUSTOM, 39)

	-- Abyssal Shatter -- 69412
	AddRecipe(69412, 445, 49640, Q.COMMON, V.WOTLK, 445, 445, 447, 450)
	self:AddRecipeFlags(69412, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:AddRecipeAcquire(69412, A.TRAINER, 28693, A.TRAINER, 26990, A.TRAINER, 26906, A.TRAINER, 26954, A.TRAINER, 26980, A.TRAINER, 33583)

	-- Enchant Gloves - Angler -- 71692
	AddRecipe(71692, 375, nil, Q.UNCOMMON, V.WOTLK, 375, 385, 392, 400)
	self:AddRecipeFlags(71692, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOP, F.RBOP)
	self:AddRecipeAcquire(71692, A.MOB, 26343)

	return num_recipes
end
